#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .front_faces_transparent import front_faces_transparent
from .projection_1 import projection
from .axes_1 import axes
from .ruler import ruler
from .title import title
from .boundary_marker import boundary_marker
from .anti_aliasing import anti_aliasing
from .reflections import reflections
from .static_shadows import static_shadows
from .dynamic_shadows import dynamic_shadows
from .grid_plane import grid_plane
from .headlights import headlights
from .lighting import lighting
from .view_name import view_name
class display_states_child(Group):
    """
    'child_object_type' of display_states.
    """

    fluent_name = "child-object-type"

    child_names = \
        ['front_faces_transparent', 'projection', 'axes', 'ruler', 'title',
         'boundary_marker', 'anti_aliasing', 'reflections', 'static_shadows',
         'dynamic_shadows', 'grid_plane', 'headlights', 'lighting',
         'view_name']

    front_faces_transparent: front_faces_transparent = front_faces_transparent
    """
    front_faces_transparent child of display_states_child.
    """
    projection: projection = projection
    """
    projection child of display_states_child.
    """
    axes: axes = axes
    """
    axes child of display_states_child.
    """
    ruler: ruler = ruler
    """
    ruler child of display_states_child.
    """
    title: title = title
    """
    title child of display_states_child.
    """
    boundary_marker: boundary_marker = boundary_marker
    """
    boundary_marker child of display_states_child.
    """
    anti_aliasing: anti_aliasing = anti_aliasing
    """
    anti_aliasing child of display_states_child.
    """
    reflections: reflections = reflections
    """
    reflections child of display_states_child.
    """
    static_shadows: static_shadows = static_shadows
    """
    static_shadows child of display_states_child.
    """
    dynamic_shadows: dynamic_shadows = dynamic_shadows
    """
    dynamic_shadows child of display_states_child.
    """
    grid_plane: grid_plane = grid_plane
    """
    grid_plane child of display_states_child.
    """
    headlights: headlights = headlights
    """
    headlights child of display_states_child.
    """
    lighting: lighting = lighting
    """
    lighting child of display_states_child.
    """
    view_name: view_name = view_name
    """
    view_name child of display_states_child.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .methods_2 import methods
from .x import x
from .y import y
from .z import z
from .point_vector import point_vector
from .point_normal import point_normal
from .compute_from_view_plane import compute_from_view_plane
from .surface_aligned_normal import surface_aligned_normal
from .p0_1 import p0
from .p1 import p1
from .p2 import p2
from .bounded import bounded
from .sample_point import sample_point
from .edges_2 import edges
class plane_surface_child(Group):
    """
    'child_object_type' of plane_surface.
    """

    fluent_name = "child-object-type"

    child_names = \
        ['methods', 'x', 'y', 'z', 'point_vector', 'point_normal',
         'compute_from_view_plane', 'surface_aligned_normal', 'p0', 'p1',
         'p2', 'bounded', 'sample_point', 'edges']

    methods: methods = methods
    """
    methods child of plane_surface_child.
    """
    x: x = x
    """
    x child of plane_surface_child.
    """
    y: y = y
    """
    y child of plane_surface_child.
    """
    z: z = z
    """
    z child of plane_surface_child.
    """
    point_vector: point_vector = point_vector
    """
    point_vector child of plane_surface_child.
    """
    point_normal: point_normal = point_normal
    """
    point_normal child of plane_surface_child.
    """
    compute_from_view_plane: compute_from_view_plane = compute_from_view_plane
    """
    compute_from_view_plane child of plane_surface_child.
    """
    surface_aligned_normal: surface_aligned_normal = surface_aligned_normal
    """
    surface_aligned_normal child of plane_surface_child.
    """
    p0: p0 = p0
    """
    p0 child of plane_surface_child.
    """
    p1: p1 = p1
    """
    p1 child of plane_surface_child.
    """
    p2: p2 = p2
    """
    p2 child of plane_surface_child.
    """
    bounded: bounded = bounded
    """
    bounded child of plane_surface_child.
    """
    sample_point: sample_point = sample_point
    """
    sample_point child of plane_surface_child.
    """
    edges: edges = edges
    """
    edges child of plane_surface_child.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .velocity_inlet_child import velocity_inlet_child

class velocity_inlet(NamedObject[velocity_inlet_child], _NonCreatableNamedObjectMixin[velocity_inlet_child]):
    """
    'velocity_inlet' child.
    """

    fluent_name = "velocity-inlet"

    child_object_type: velocity_inlet_child = velocity_inlet_child
    """
    child_object_type of velocity_inlet.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .option_2 import option
from .automatic import automatic
from .manual import manual
class coloring(Group):
    """
    'coloring' child.
    """

    fluent_name = "coloring"

    child_names = \
        ['option', 'automatic', 'manual']

    option: option = option
    """
    option child of coloring.
    """
    automatic: automatic = automatic
    """
    automatic child of coloring.
    """
    manual: manual = manual
    """
    manual child of coloring.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

class enable_turb_damping(Boolean):
    """
    Enable/Disable Turbulence Damping.
    """

    fluent_name = "enable-turb-damping?"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .domain import domain
from .cell_function import cell_function
from .min_val import min_val
from .max_val import max_val
from .num_division import num_division
from .set_all_zones import set_all_zones
from .threads_list import threads_list
from .file_name_1 import file_name
from .overwrite import overwrite
class print_histogram(Command):
    """
    Print a histogram of a scalar quantity.
    
    Parameters
    ----------
        domain : str
            'domain' child.
        cell_function : str
            'cell_function' child.
        min_val : real
            'min_val' child.
        max_val : real
            'max_val' child.
        num_division : int
            'num_division' child.
        set_all_zones : bool
            'set_all_zones' child.
        threads_list : typing.List[str]
            'threads_list' child.
        file_name : str
            'file_name' child.
        overwrite : bool
            'overwrite' child.
    
    """

    fluent_name = "print-histogram"

    argument_names = \
        ['domain', 'cell_function', 'min_val', 'max_val', 'num_division',
         'set_all_zones', 'threads_list', 'file_name', 'overwrite']

    domain: domain = domain
    """
    domain argument of print_histogram.
    """
    cell_function: cell_function = cell_function
    """
    cell_function argument of print_histogram.
    """
    min_val: min_val = min_val
    """
    min_val argument of print_histogram.
    """
    max_val: max_val = max_val
    """
    max_val argument of print_histogram.
    """
    num_division: num_division = num_division
    """
    num_division argument of print_histogram.
    """
    set_all_zones: set_all_zones = set_all_zones
    """
    set_all_zones argument of print_histogram.
    """
    threads_list: threads_list = threads_list
    """
    threads_list argument of print_histogram.
    """
    file_name: file_name = file_name
    """
    file_name argument of print_histogram.
    """
    overwrite: overwrite = overwrite
    """
    overwrite argument of print_histogram.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .write_to_file import write_to_file
from .file_name_1 import file_name
from .overwrite import overwrite
class summary(Command):
    """
    Print report summary.
    
    Parameters
    ----------
        write_to_file : bool
            'write_to_file' child.
        file_name : str
            'file_name' child.
        overwrite : bool
            'overwrite' child.
    
    """

    fluent_name = "summary"

    argument_names = \
        ['write_to_file', 'file_name', 'overwrite']

    write_to_file: write_to_file = write_to_file
    """
    write_to_file argument of summary.
    """
    file_name: file_name = file_name
    """
    file_name argument of summary.
    """
    overwrite: overwrite = overwrite
    """
    overwrite argument of summary.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .phase_16 import phase
from .geom_disable import geom_disable
from .geom_dir_spec import geom_dir_spec
from .geom_dir_x import geom_dir_x
from .geom_dir_y import geom_dir_y
from .geom_dir_z import geom_dir_z
from .geom_levels import geom_levels
from .geom_bgthread import geom_bgthread
from .p import p
from .m import m
from .t import t
from .non_equil_boundary import non_equil_boundary
from .tve import tve
from .coordinate_system import coordinate_system
from .ni_1 import ni
from .nj_1 import nj
from .nk_1 import nk
from .flow_direction_component import flow_direction_component
from .axis_direction_component_1 import axis_direction_component
from .axis_origin_component_1 import axis_origin_component
from .ke_spec import ke_spec
from .nut import nut
from .kl import kl
from .intermit import intermit
from .k import k
from .e import e
from .o import o
from .v2 import v2
from .turb_intensity import turb_intensity
from .turb_length_scale import turb_length_scale
from .turb_hydraulic_diam import turb_hydraulic_diam
from .turb_viscosity_ratio import turb_viscosity_ratio
from .turb_viscosity_ratio_profile import turb_viscosity_ratio_profile
from .rst_spec import rst_spec
from .uu import uu
from .vv import vv
from .ww import ww
from .uv import uv
from .vw import vw
from .uw import uw
from .ksgs_spec import ksgs_spec
from .ksgs import ksgs
from .sgs_turb_intensity import sgs_turb_intensity
from .radiation_bc import radiation_bc
from .radial_direction_component import radial_direction_component
from .coll_dtheta import coll_dtheta
from .coll_dphi import coll_dphi
from .band_q_irrad import band_q_irrad
from .band_q_irrad_diffuse import band_q_irrad_diffuse
from .parallel_collimated_beam import parallel_collimated_beam
from .solar_direction import solar_direction
from .solar_irradiation import solar_irradiation
from .t_b_b_spec import t_b_b_spec
from .t_b_b import t_b_b
from .in_emiss import in_emiss
from .fmean import fmean
from .fvar import fvar
from .fmean2 import fmean2
from .fvar2 import fvar2
from .species_in_mole_fractions import species_in_mole_fractions
from .mf import mf
from .elec_potential_type import elec_potential_type
from .potential_value import potential_value
from .dual_potential_type import dual_potential_type
from .dual_potential_value import dual_potential_value
from .x_displacement_type import x_displacement_type
from .x_displacement_value import x_displacement_value
from .y_displacement_type import y_displacement_type
from .y_displacement_value import y_displacement_value
from .z_displacement_type import z_displacement_type
from .z_displacement_value import z_displacement_value
from .prob_mode_1 import prob_mode_1
from .prob_mode_2 import prob_mode_2
from .prob_mode_3 import prob_mode_3
from .pollut_no import pollut_no
from .pollut_hcn import pollut_hcn
from .pollut_nh3 import pollut_nh3
from .pollut_n2o import pollut_n2o
from .pollut_urea import pollut_urea
from .pollut_hnco import pollut_hnco
from .pollut_nco import pollut_nco
from .pollut_so2 import pollut_so2
from .pollut_h2s import pollut_h2s
from .pollut_so3 import pollut_so3
from .pollut_sh import pollut_sh
from .pollut_so import pollut_so
from .pollut_soot import pollut_soot
from .pollut_nuclei import pollut_nuclei
from .pollut_ctar import pollut_ctar
from .pollut_hg import pollut_hg
from .pollut_hgcl2 import pollut_hgcl2
from .pollut_hcl import pollut_hcl
from .pollut_hgo import pollut_hgo
from .pollut_cl import pollut_cl
from .pollut_cl2 import pollut_cl2
from .pollut_hgcl import pollut_hgcl
from .pollut_hocl import pollut_hocl
from .fensapice_flow_bc_subtype import fensapice_flow_bc_subtype
from .fensapice_drop_bccustom import fensapice_drop_bccustom
from .fensapice_drop_lwc import fensapice_drop_lwc
from .fensapice_drop_dtemp import fensapice_drop_dtemp
from .fensapice_drop_ddiam import fensapice_drop_ddiam
from .fensapice_drop_dv import fensapice_drop_dv
from .fensapice_drop_dx import fensapice_drop_dx
from .fensapice_drop_dy import fensapice_drop_dy
from .fensapice_drop_dz import fensapice_drop_dz
from .fensapice_dpm_surface_injection import fensapice_dpm_surface_injection
from .fensapice_dpm_inj_nstream import fensapice_dpm_inj_nstream
from .fensapice_drop_icc import fensapice_drop_icc
from .fensapice_drop_ctemp import fensapice_drop_ctemp
from .fensapice_drop_cdiam import fensapice_drop_cdiam
from .fensapice_drop_cv import fensapice_drop_cv
from .fensapice_drop_cx import fensapice_drop_cx
from .fensapice_drop_cy import fensapice_drop_cy
from .fensapice_drop_cz import fensapice_drop_cz
from .fensapice_drop_vrh import fensapice_drop_vrh
from .fensapice_drop_vrh_1 import fensapice_drop_vrh_1
from .fensapice_drop_vc import fensapice_drop_vc
from .uds_bc import uds_bc
from .uds import uds
from .dpm_bc_type import dpm_bc_type
from .dpm_bc_collision_partner import dpm_bc_collision_partner
from .reinj_inj import reinj_inj
from .dpm_bc_udf import dpm_bc_udf
from .solar_fluxes import solar_fluxes
from .solar_shining_factor import solar_shining_factor
from .radiating_s2s_surface import radiating_s2s_surface
class pressure_far_field_child(Group):
    """
    'child_object_type' of pressure_far_field.
    """

    fluent_name = "child-object-type"

    child_names = \
        ['phase', 'geom_disable', 'geom_dir_spec', 'geom_dir_x', 'geom_dir_y',
         'geom_dir_z', 'geom_levels', 'geom_bgthread', 'p', 'm', 't',
         'non_equil_boundary', 'tve', 'coordinate_system', 'ni', 'nj', 'nk',
         'flow_direction_component', 'axis_direction_component',
         'axis_origin_component', 'ke_spec', 'nut', 'kl', 'intermit', 'k',
         'e', 'o', 'v2', 'turb_intensity', 'turb_length_scale',
         'turb_hydraulic_diam', 'turb_viscosity_ratio',
         'turb_viscosity_ratio_profile', 'rst_spec', 'uu', 'vv', 'ww', 'uv',
         'vw', 'uw', 'ksgs_spec', 'ksgs', 'sgs_turb_intensity',
         'radiation_bc', 'radial_direction_component', 'coll_dtheta',
         'coll_dphi', 'band_q_irrad', 'band_q_irrad_diffuse',
         'parallel_collimated_beam', 'solar_direction', 'solar_irradiation',
         't_b_b_spec', 't_b_b', 'in_emiss', 'fmean', 'fvar', 'fmean2',
         'fvar2', 'species_in_mole_fractions', 'mf', 'elec_potential_type',
         'potential_value', 'dual_potential_type', 'dual_potential_value',
         'x_displacement_type', 'x_displacement_value', 'y_displacement_type',
         'y_displacement_value', 'z_displacement_type',
         'z_displacement_value', 'prob_mode_1', 'prob_mode_2', 'prob_mode_3',
         'pollut_no', 'pollut_hcn', 'pollut_nh3', 'pollut_n2o', 'pollut_urea',
         'pollut_hnco', 'pollut_nco', 'pollut_so2', 'pollut_h2s',
         'pollut_so3', 'pollut_sh', 'pollut_so', 'pollut_soot',
         'pollut_nuclei', 'pollut_ctar', 'pollut_hg', 'pollut_hgcl2',
         'pollut_hcl', 'pollut_hgo', 'pollut_cl', 'pollut_cl2', 'pollut_hgcl',
         'pollut_hocl', 'fensapice_flow_bc_subtype',
         'fensapice_drop_bccustom', 'fensapice_drop_lwc',
         'fensapice_drop_dtemp', 'fensapice_drop_ddiam', 'fensapice_drop_dv',
         'fensapice_drop_dx', 'fensapice_drop_dy', 'fensapice_drop_dz',
         'fensapice_dpm_surface_injection', 'fensapice_dpm_inj_nstream',
         'fensapice_drop_icc', 'fensapice_drop_ctemp', 'fensapice_drop_cdiam',
         'fensapice_drop_cv', 'fensapice_drop_cx', 'fensapice_drop_cy',
         'fensapice_drop_cz', 'fensapice_drop_vrh', 'fensapice_drop_vrh_1',
         'fensapice_drop_vc', 'uds_bc', 'uds', 'dpm_bc_type',
         'dpm_bc_collision_partner', 'reinj_inj', 'dpm_bc_udf',
         'solar_fluxes', 'solar_shining_factor', 'radiating_s2s_surface']

    phase: phase = phase
    """
    phase child of pressure_far_field_child.
    """
    geom_disable: geom_disable = geom_disable
    """
    geom_disable child of pressure_far_field_child.
    """
    geom_dir_spec: geom_dir_spec = geom_dir_spec
    """
    geom_dir_spec child of pressure_far_field_child.
    """
    geom_dir_x: geom_dir_x = geom_dir_x
    """
    geom_dir_x child of pressure_far_field_child.
    """
    geom_dir_y: geom_dir_y = geom_dir_y
    """
    geom_dir_y child of pressure_far_field_child.
    """
    geom_dir_z: geom_dir_z = geom_dir_z
    """
    geom_dir_z child of pressure_far_field_child.
    """
    geom_levels: geom_levels = geom_levels
    """
    geom_levels child of pressure_far_field_child.
    """
    geom_bgthread: geom_bgthread = geom_bgthread
    """
    geom_bgthread child of pressure_far_field_child.
    """
    p: p = p
    """
    p child of pressure_far_field_child.
    """
    m: m = m
    """
    m child of pressure_far_field_child.
    """
    t: t = t
    """
    t child of pressure_far_field_child.
    """
    non_equil_boundary: non_equil_boundary = non_equil_boundary
    """
    non_equil_boundary child of pressure_far_field_child.
    """
    tve: tve = tve
    """
    tve child of pressure_far_field_child.
    """
    coordinate_system: coordinate_system = coordinate_system
    """
    coordinate_system child of pressure_far_field_child.
    """
    ni: ni = ni
    """
    ni child of pressure_far_field_child.
    """
    nj: nj = nj
    """
    nj child of pressure_far_field_child.
    """
    nk: nk = nk
    """
    nk child of pressure_far_field_child.
    """
    flow_direction_component: flow_direction_component = flow_direction_component
    """
    flow_direction_component child of pressure_far_field_child.
    """
    axis_direction_component: axis_direction_component = axis_direction_component
    """
    axis_direction_component child of pressure_far_field_child.
    """
    axis_origin_component: axis_origin_component = axis_origin_component
    """
    axis_origin_component child of pressure_far_field_child.
    """
    ke_spec: ke_spec = ke_spec
    """
    ke_spec child of pressure_far_field_child.
    """
    nut: nut = nut
    """
    nut child of pressure_far_field_child.
    """
    kl: kl = kl
    """
    kl child of pressure_far_field_child.
    """
    intermit: intermit = intermit
    """
    intermit child of pressure_far_field_child.
    """
    k: k = k
    """
    k child of pressure_far_field_child.
    """
    e: e = e
    """
    e child of pressure_far_field_child.
    """
    o: o = o
    """
    o child of pressure_far_field_child.
    """
    v2: v2 = v2
    """
    v2 child of pressure_far_field_child.
    """
    turb_intensity: turb_intensity = turb_intensity
    """
    turb_intensity child of pressure_far_field_child.
    """
    turb_length_scale: turb_length_scale = turb_length_scale
    """
    turb_length_scale child of pressure_far_field_child.
    """
    turb_hydraulic_diam: turb_hydraulic_diam = turb_hydraulic_diam
    """
    turb_hydraulic_diam child of pressure_far_field_child.
    """
    turb_viscosity_ratio: turb_viscosity_ratio = turb_viscosity_ratio
    """
    turb_viscosity_ratio child of pressure_far_field_child.
    """
    turb_viscosity_ratio_profile: turb_viscosity_ratio_profile = turb_viscosity_ratio_profile
    """
    turb_viscosity_ratio_profile child of pressure_far_field_child.
    """
    rst_spec: rst_spec = rst_spec
    """
    rst_spec child of pressure_far_field_child.
    """
    uu: uu = uu
    """
    uu child of pressure_far_field_child.
    """
    vv: vv = vv
    """
    vv child of pressure_far_field_child.
    """
    ww: ww = ww
    """
    ww child of pressure_far_field_child.
    """
    uv: uv = uv
    """
    uv child of pressure_far_field_child.
    """
    vw: vw = vw
    """
    vw child of pressure_far_field_child.
    """
    uw: uw = uw
    """
    uw child of pressure_far_field_child.
    """
    ksgs_spec: ksgs_spec = ksgs_spec
    """
    ksgs_spec child of pressure_far_field_child.
    """
    ksgs: ksgs = ksgs
    """
    ksgs child of pressure_far_field_child.
    """
    sgs_turb_intensity: sgs_turb_intensity = sgs_turb_intensity
    """
    sgs_turb_intensity child of pressure_far_field_child.
    """
    radiation_bc: radiation_bc = radiation_bc
    """
    radiation_bc child of pressure_far_field_child.
    """
    radial_direction_component: radial_direction_component = radial_direction_component
    """
    radial_direction_component child of pressure_far_field_child.
    """
    coll_dtheta: coll_dtheta = coll_dtheta
    """
    coll_dtheta child of pressure_far_field_child.
    """
    coll_dphi: coll_dphi = coll_dphi
    """
    coll_dphi child of pressure_far_field_child.
    """
    band_q_irrad: band_q_irrad = band_q_irrad
    """
    band_q_irrad child of pressure_far_field_child.
    """
    band_q_irrad_diffuse: band_q_irrad_diffuse = band_q_irrad_diffuse
    """
    band_q_irrad_diffuse child of pressure_far_field_child.
    """
    parallel_collimated_beam: parallel_collimated_beam = parallel_collimated_beam
    """
    parallel_collimated_beam child of pressure_far_field_child.
    """
    solar_direction: solar_direction = solar_direction
    """
    solar_direction child of pressure_far_field_child.
    """
    solar_irradiation: solar_irradiation = solar_irradiation
    """
    solar_irradiation child of pressure_far_field_child.
    """
    t_b_b_spec: t_b_b_spec = t_b_b_spec
    """
    t_b_b_spec child of pressure_far_field_child.
    """
    t_b_b: t_b_b = t_b_b
    """
    t_b_b child of pressure_far_field_child.
    """
    in_emiss: in_emiss = in_emiss
    """
    in_emiss child of pressure_far_field_child.
    """
    fmean: fmean = fmean
    """
    fmean child of pressure_far_field_child.
    """
    fvar: fvar = fvar
    """
    fvar child of pressure_far_field_child.
    """
    fmean2: fmean2 = fmean2
    """
    fmean2 child of pressure_far_field_child.
    """
    fvar2: fvar2 = fvar2
    """
    fvar2 child of pressure_far_field_child.
    """
    species_in_mole_fractions: species_in_mole_fractions = species_in_mole_fractions
    """
    species_in_mole_fractions child of pressure_far_field_child.
    """
    mf: mf = mf
    """
    mf child of pressure_far_field_child.
    """
    elec_potential_type: elec_potential_type = elec_potential_type
    """
    elec_potential_type child of pressure_far_field_child.
    """
    potential_value: potential_value = potential_value
    """
    potential_value child of pressure_far_field_child.
    """
    dual_potential_type: dual_potential_type = dual_potential_type
    """
    dual_potential_type child of pressure_far_field_child.
    """
    dual_potential_value: dual_potential_value = dual_potential_value
    """
    dual_potential_value child of pressure_far_field_child.
    """
    x_displacement_type: x_displacement_type = x_displacement_type
    """
    x_displacement_type child of pressure_far_field_child.
    """
    x_displacement_value: x_displacement_value = x_displacement_value
    """
    x_displacement_value child of pressure_far_field_child.
    """
    y_displacement_type: y_displacement_type = y_displacement_type
    """
    y_displacement_type child of pressure_far_field_child.
    """
    y_displacement_value: y_displacement_value = y_displacement_value
    """
    y_displacement_value child of pressure_far_field_child.
    """
    z_displacement_type: z_displacement_type = z_displacement_type
    """
    z_displacement_type child of pressure_far_field_child.
    """
    z_displacement_value: z_displacement_value = z_displacement_value
    """
    z_displacement_value child of pressure_far_field_child.
    """
    prob_mode_1: prob_mode_1 = prob_mode_1
    """
    prob_mode_1 child of pressure_far_field_child.
    """
    prob_mode_2: prob_mode_2 = prob_mode_2
    """
    prob_mode_2 child of pressure_far_field_child.
    """
    prob_mode_3: prob_mode_3 = prob_mode_3
    """
    prob_mode_3 child of pressure_far_field_child.
    """
    pollut_no: pollut_no = pollut_no
    """
    pollut_no child of pressure_far_field_child.
    """
    pollut_hcn: pollut_hcn = pollut_hcn
    """
    pollut_hcn child of pressure_far_field_child.
    """
    pollut_nh3: pollut_nh3 = pollut_nh3
    """
    pollut_nh3 child of pressure_far_field_child.
    """
    pollut_n2o: pollut_n2o = pollut_n2o
    """
    pollut_n2o child of pressure_far_field_child.
    """
    pollut_urea: pollut_urea = pollut_urea
    """
    pollut_urea child of pressure_far_field_child.
    """
    pollut_hnco: pollut_hnco = pollut_hnco
    """
    pollut_hnco child of pressure_far_field_child.
    """
    pollut_nco: pollut_nco = pollut_nco
    """
    pollut_nco child of pressure_far_field_child.
    """
    pollut_so2: pollut_so2 = pollut_so2
    """
    pollut_so2 child of pressure_far_field_child.
    """
    pollut_h2s: pollut_h2s = pollut_h2s
    """
    pollut_h2s child of pressure_far_field_child.
    """
    pollut_so3: pollut_so3 = pollut_so3
    """
    pollut_so3 child of pressure_far_field_child.
    """
    pollut_sh: pollut_sh = pollut_sh
    """
    pollut_sh child of pressure_far_field_child.
    """
    pollut_so: pollut_so = pollut_so
    """
    pollut_so child of pressure_far_field_child.
    """
    pollut_soot: pollut_soot = pollut_soot
    """
    pollut_soot child of pressure_far_field_child.
    """
    pollut_nuclei: pollut_nuclei = pollut_nuclei
    """
    pollut_nuclei child of pressure_far_field_child.
    """
    pollut_ctar: pollut_ctar = pollut_ctar
    """
    pollut_ctar child of pressure_far_field_child.
    """
    pollut_hg: pollut_hg = pollut_hg
    """
    pollut_hg child of pressure_far_field_child.
    """
    pollut_hgcl2: pollut_hgcl2 = pollut_hgcl2
    """
    pollut_hgcl2 child of pressure_far_field_child.
    """
    pollut_hcl: pollut_hcl = pollut_hcl
    """
    pollut_hcl child of pressure_far_field_child.
    """
    pollut_hgo: pollut_hgo = pollut_hgo
    """
    pollut_hgo child of pressure_far_field_child.
    """
    pollut_cl: pollut_cl = pollut_cl
    """
    pollut_cl child of pressure_far_field_child.
    """
    pollut_cl2: pollut_cl2 = pollut_cl2
    """
    pollut_cl2 child of pressure_far_field_child.
    """
    pollut_hgcl: pollut_hgcl = pollut_hgcl
    """
    pollut_hgcl child of pressure_far_field_child.
    """
    pollut_hocl: pollut_hocl = pollut_hocl
    """
    pollut_hocl child of pressure_far_field_child.
    """
    fensapice_flow_bc_subtype: fensapice_flow_bc_subtype = fensapice_flow_bc_subtype
    """
    fensapice_flow_bc_subtype child of pressure_far_field_child.
    """
    fensapice_drop_bccustom: fensapice_drop_bccustom = fensapice_drop_bccustom
    """
    fensapice_drop_bccustom child of pressure_far_field_child.
    """
    fensapice_drop_lwc: fensapice_drop_lwc = fensapice_drop_lwc
    """
    fensapice_drop_lwc child of pressure_far_field_child.
    """
    fensapice_drop_dtemp: fensapice_drop_dtemp = fensapice_drop_dtemp
    """
    fensapice_drop_dtemp child of pressure_far_field_child.
    """
    fensapice_drop_ddiam: fensapice_drop_ddiam = fensapice_drop_ddiam
    """
    fensapice_drop_ddiam child of pressure_far_field_child.
    """
    fensapice_drop_dv: fensapice_drop_dv = fensapice_drop_dv
    """
    fensapice_drop_dv child of pressure_far_field_child.
    """
    fensapice_drop_dx: fensapice_drop_dx = fensapice_drop_dx
    """
    fensapice_drop_dx child of pressure_far_field_child.
    """
    fensapice_drop_dy: fensapice_drop_dy = fensapice_drop_dy
    """
    fensapice_drop_dy child of pressure_far_field_child.
    """
    fensapice_drop_dz: fensapice_drop_dz = fensapice_drop_dz
    """
    fensapice_drop_dz child of pressure_far_field_child.
    """
    fensapice_dpm_surface_injection: fensapice_dpm_surface_injection = fensapice_dpm_surface_injection
    """
    fensapice_dpm_surface_injection child of pressure_far_field_child.
    """
    fensapice_dpm_inj_nstream: fensapice_dpm_inj_nstream = fensapice_dpm_inj_nstream
    """
    fensapice_dpm_inj_nstream child of pressure_far_field_child.
    """
    fensapice_drop_icc: fensapice_drop_icc = fensapice_drop_icc
    """
    fensapice_drop_icc child of pressure_far_field_child.
    """
    fensapice_drop_ctemp: fensapice_drop_ctemp = fensapice_drop_ctemp
    """
    fensapice_drop_ctemp child of pressure_far_field_child.
    """
    fensapice_drop_cdiam: fensapice_drop_cdiam = fensapice_drop_cdiam
    """
    fensapice_drop_cdiam child of pressure_far_field_child.
    """
    fensapice_drop_cv: fensapice_drop_cv = fensapice_drop_cv
    """
    fensapice_drop_cv child of pressure_far_field_child.
    """
    fensapice_drop_cx: fensapice_drop_cx = fensapice_drop_cx
    """
    fensapice_drop_cx child of pressure_far_field_child.
    """
    fensapice_drop_cy: fensapice_drop_cy = fensapice_drop_cy
    """
    fensapice_drop_cy child of pressure_far_field_child.
    """
    fensapice_drop_cz: fensapice_drop_cz = fensapice_drop_cz
    """
    fensapice_drop_cz child of pressure_far_field_child.
    """
    fensapice_drop_vrh: fensapice_drop_vrh = fensapice_drop_vrh
    """
    fensapice_drop_vrh child of pressure_far_field_child.
    """
    fensapice_drop_vrh_1: fensapice_drop_vrh_1 = fensapice_drop_vrh_1
    """
    fensapice_drop_vrh_1 child of pressure_far_field_child.
    """
    fensapice_drop_vc: fensapice_drop_vc = fensapice_drop_vc
    """
    fensapice_drop_vc child of pressure_far_field_child.
    """
    uds_bc: uds_bc = uds_bc
    """
    uds_bc child of pressure_far_field_child.
    """
    uds: uds = uds
    """
    uds child of pressure_far_field_child.
    """
    dpm_bc_type: dpm_bc_type = dpm_bc_type
    """
    dpm_bc_type child of pressure_far_field_child.
    """
    dpm_bc_collision_partner: dpm_bc_collision_partner = dpm_bc_collision_partner
    """
    dpm_bc_collision_partner child of pressure_far_field_child.
    """
    reinj_inj: reinj_inj = reinj_inj
    """
    reinj_inj child of pressure_far_field_child.
    """
    dpm_bc_udf: dpm_bc_udf = dpm_bc_udf
    """
    dpm_bc_udf child of pressure_far_field_child.
    """
    solar_fluxes: solar_fluxes = solar_fluxes
    """
    solar_fluxes child of pressure_far_field_child.
    """
    solar_shining_factor: solar_shining_factor = solar_shining_factor
    """
    solar_shining_factor child of pressure_far_field_child.
    """
    radiating_s2s_surface: radiating_s2s_surface = radiating_s2s_surface
    """
    radiating_s2s_surface child of pressure_far_field_child.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .delete import delete
from .display import display
from .read_2 import read
class surface_mesh(Group):
    """
    Enter the surface mesh menu.
    """

    fluent_name = "surface-mesh"

    command_names = \
        ['delete', 'display', 'read']

    delete: delete = delete
    """
    delete command of surface_mesh.
    """
    display: display = display
    """
    display command of surface_mesh.
    """
    read: read = read
    """
    read command of surface_mesh.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .domain import domain
from .cell_zones_1 import cell_zones
from .register_id import register_id
from .variable import variable
from .patch_velocity import patch_velocity
from .use_custom_field_function import use_custom_field_function
from .custom_field_function_name import custom_field_function_name
from .value import value
class calculate_patch(Command):
    """
    Patch a value for a flow variable in the domain.
    
    Parameters
    ----------
        domain : str
            'domain' child.
        cell_zones : typing.List[str]
            'cell_zones' child.
        register_id : typing.List[str]
            'register_id' child.
        variable : str
            'variable' child.
        patch_velocity : bool
            'patch_velocity' child.
        use_custom_field_function : bool
            'use_custom_field_function' child.
        custom_field_function_name : str
            'custom_field_function_name' child.
        value : real
            'value' child.
    
    """

    fluent_name = "calculate-patch"

    argument_names = \
        ['domain', 'cell_zones', 'register_id', 'variable', 'patch_velocity',
         'use_custom_field_function', 'custom_field_function_name', 'value']

    domain: domain = domain
    """
    domain argument of calculate_patch.
    """
    cell_zones: cell_zones = cell_zones
    """
    cell_zones argument of calculate_patch.
    """
    register_id: register_id = register_id
    """
    register_id argument of calculate_patch.
    """
    variable: variable = variable
    """
    variable argument of calculate_patch.
    """
    patch_velocity: patch_velocity = patch_velocity
    """
    patch_velocity argument of calculate_patch.
    """
    use_custom_field_function: use_custom_field_function = use_custom_field_function
    """
    use_custom_field_function argument of calculate_patch.
    """
    custom_field_function_name: custom_field_function_name = custom_field_function_name
    """
    custom_field_function_name argument of calculate_patch.
    """
    value: value = value
    """
    value argument of calculate_patch.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .faces_1 import faces
from .edges_1 import edges
from .nodes_1 import nodes
from .material_color import material_color
class manual(Group):
    """
    'manual' child.
    """

    fluent_name = "manual"

    child_names = \
        ['faces', 'edges', 'nodes', 'material_color']

    faces: faces = faces
    """
    faces child of manual.
    """
    edges: edges = edges
    """
    edges child of manual.
    """
    nodes: nodes = nodes
    """
    nodes child of manual.
    """
    material_color: material_color = material_color
    """
    material_color child of manual.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .axis import axis
from .degassing import degassing
from .exhaust_fan import exhaust_fan
from .fan import fan
from .geometry import geometry
from .inlet_vent import inlet_vent
from .intake_fan import intake_fan
from .interface import interface
from .interior import interior
from .mass_flow_inlet import mass_flow_inlet
from .mass_flow_outlet import mass_flow_outlet
from .network import network
from .network_end import network_end
from .outflow import outflow
from .outlet_vent import outlet_vent
from .overset import overset
from .periodic import periodic
from .porous_jump import porous_jump
from .pressure_far_field import pressure_far_field
from .pressure_inlet import pressure_inlet
from .pressure_outlet import pressure_outlet
from .radiator import radiator
from .rans_les_interface import rans_les_interface
from .recirculation_inlet import recirculation_inlet
from .recirculation_outlet import recirculation_outlet
from .shadow import shadow
from .symmetry import symmetry
from .velocity_inlet import velocity_inlet
from .wall import wall
class boundary_conditions(Group):
    """
    'boundary_conditions' child.
    """

    fluent_name = "boundary-conditions"

    child_names = \
        ['axis', 'degassing', 'exhaust_fan', 'fan', 'geometry', 'inlet_vent',
         'intake_fan', 'interface', 'interior', 'mass_flow_inlet',
         'mass_flow_outlet', 'network', 'network_end', 'outflow',
         'outlet_vent', 'overset', 'periodic', 'porous_jump',
         'pressure_far_field', 'pressure_inlet', 'pressure_outlet',
         'radiator', 'rans_les_interface', 'recirculation_inlet',
         'recirculation_outlet', 'shadow', 'symmetry', 'velocity_inlet',
         'wall']

    axis: axis = axis
    """
    axis child of boundary_conditions.
    """
    degassing: degassing = degassing
    """
    degassing child of boundary_conditions.
    """
    exhaust_fan: exhaust_fan = exhaust_fan
    """
    exhaust_fan child of boundary_conditions.
    """
    fan: fan = fan
    """
    fan child of boundary_conditions.
    """
    geometry: geometry = geometry
    """
    geometry child of boundary_conditions.
    """
    inlet_vent: inlet_vent = inlet_vent
    """
    inlet_vent child of boundary_conditions.
    """
    intake_fan: intake_fan = intake_fan
    """
    intake_fan child of boundary_conditions.
    """
    interface: interface = interface
    """
    interface child of boundary_conditions.
    """
    interior: interior = interior
    """
    interior child of boundary_conditions.
    """
    mass_flow_inlet: mass_flow_inlet = mass_flow_inlet
    """
    mass_flow_inlet child of boundary_conditions.
    """
    mass_flow_outlet: mass_flow_outlet = mass_flow_outlet
    """
    mass_flow_outlet child of boundary_conditions.
    """
    network: network = network
    """
    network child of boundary_conditions.
    """
    network_end: network_end = network_end
    """
    network_end child of boundary_conditions.
    """
    outflow: outflow = outflow
    """
    outflow child of boundary_conditions.
    """
    outlet_vent: outlet_vent = outlet_vent
    """
    outlet_vent child of boundary_conditions.
    """
    overset: overset = overset
    """
    overset child of boundary_conditions.
    """
    periodic: periodic = periodic
    """
    periodic child of boundary_conditions.
    """
    porous_jump: porous_jump = porous_jump
    """
    porous_jump child of boundary_conditions.
    """
    pressure_far_field: pressure_far_field = pressure_far_field
    """
    pressure_far_field child of boundary_conditions.
    """
    pressure_inlet: pressure_inlet = pressure_inlet
    """
    pressure_inlet child of boundary_conditions.
    """
    pressure_outlet: pressure_outlet = pressure_outlet
    """
    pressure_outlet child of boundary_conditions.
    """
    radiator: radiator = radiator
    """
    radiator child of boundary_conditions.
    """
    rans_les_interface: rans_les_interface = rans_les_interface
    """
    rans_les_interface child of boundary_conditions.
    """
    recirculation_inlet: recirculation_inlet = recirculation_inlet
    """
    recirculation_inlet child of boundary_conditions.
    """
    recirculation_outlet: recirculation_outlet = recirculation_outlet
    """
    recirculation_outlet child of boundary_conditions.
    """
    shadow: shadow = shadow
    """
    shadow child of boundary_conditions.
    """
    symmetry: symmetry = symmetry
    """
    symmetry child of boundary_conditions.
    """
    velocity_inlet: velocity_inlet = velocity_inlet
    """
    velocity_inlet child of boundary_conditions.
    """
    wall: wall = wall
    """
    wall child of boundary_conditions.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .set_ramping_length import set_ramping_length
from .number_of_timesteps import number_of_timesteps
class init_acoustics_options(Command):
    """
    'init_acoustics_options' command.
    
    Parameters
    ----------
        set_ramping_length : bool
            Enable/Disable ramping length and initialize acoustics.
        number_of_timesteps : int
            Set number of timesteps for ramping of sources.
    
    """

    fluent_name = "init-acoustics-options"

    argument_names = \
        ['set_ramping_length', 'number_of_timesteps']

    set_ramping_length: set_ramping_length = set_ramping_length
    """
    set_ramping_length argument of init_acoustics_options.
    """
    number_of_timesteps: number_of_timesteps = number_of_timesteps
    """
    number_of_timesteps argument of init_acoustics_options.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .state_name import state_name
class copy(Command):
    """
    Create a new display state with settings copied from an existing display state.
    
    Parameters
    ----------
        state_name : str
            'state_name' child.
    
    """

    fluent_name = "copy"

    argument_names = \
        ['state_name']

    state_name: state_name = state_name
    """
    state_name argument of copy.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .loaded_samples import loaded_samples
from .variable_to_sampled import variable_to_sampled
from .weighting_var import weighting_var
from .correlation_var import correlation_var
from .read_fn import read_fn
from .overwrite import overwrite
class plot_sample(Command):
    """
    'plot_sample' command.
    
    Parameters
    ----------
        loaded_samples : str
            'loaded_samples' child.
        variable_to_sampled : str
            'variable_to_sampled' child.
        weighting_var : str
            'weighting_var' child.
        correlation_var : str
            'correlation_var' child.
        read_fn : str
            'read_fn' child.
        overwrite : bool
            'overwrite' child.
    
    """

    fluent_name = "plot-sample"

    argument_names = \
        ['loaded_samples', 'variable_to_sampled', 'weighting_var',
         'correlation_var', 'read_fn', 'overwrite']

    loaded_samples: loaded_samples = loaded_samples
    """
    loaded_samples argument of plot_sample.
    """
    variable_to_sampled: variable_to_sampled = variable_to_sampled
    """
    variable_to_sampled argument of plot_sample.
    """
    weighting_var: weighting_var = weighting_var
    """
    weighting_var argument of plot_sample.
    """
    correlation_var: correlation_var = correlation_var
    """
    correlation_var argument of plot_sample.
    """
    read_fn: read_fn = read_fn
    """
    read_fn argument of plot_sample.
    """
    overwrite: overwrite = overwrite
    """
    overwrite argument of plot_sample.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .old_default_of_operating_density_method import old_default_of_operating_density_method
from .old_default_of_volume_fraction_smoothing import old_default_of_volume_fraction_smoothing
from .old_variant_of_pesto_for_cases_using_structured_mesh import old_variant_of_pesto_for_cases_using_structured_mesh
class revert_to_pre_r20_1_default_settings(Group):
    """
    Revert to pre-R20.1 multiphase flow default settings.
    """

    fluent_name = "revert-to-pre-r20.1-default-settings?"

    child_names = \
        ['old_default_of_operating_density_method',
         'old_default_of_volume_fraction_smoothing',
         'old_variant_of_pesto_for_cases_using_structured_mesh']

    old_default_of_operating_density_method: old_default_of_operating_density_method = old_default_of_operating_density_method
    """
    old_default_of_operating_density_method child of revert_to_pre_r20_1_default_settings.
    """
    old_default_of_volume_fraction_smoothing: old_default_of_volume_fraction_smoothing = old_default_of_volume_fraction_smoothing
    """
    old_default_of_volume_fraction_smoothing child of revert_to_pre_r20_1_default_settings.
    """
    old_variant_of_pesto_for_cases_using_structured_mesh: old_variant_of_pesto_for_cases_using_structured_mesh = old_variant_of_pesto_for_cases_using_structured_mesh
    """
    old_variant_of_pesto_for_cases_using_structured_mesh child of revert_to_pre_r20_1_default_settings.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .low_order_rhie_chow import low_order_rhie_chow
class rhie_chow_flux(Group):
    """
    'rhie_chow_flux' child.
    """

    fluent_name = "rhie-chow-flux"

    child_names = \
        ['low_order_rhie_chow']

    low_order_rhie_chow: low_order_rhie_chow = low_order_rhie_chow
    """
    low_order_rhie_chow child of rhie_chow_flux.
    """



################ Scheme Interpreter in Python

## (c) Peter Norvig, 2010; See http://norvig.com/lispy2.html

################ Symbol, Procedure, classes

## This code is copied from
## https://github.com/norvig/pytudes/blob/main/py/lispy.py
## and modified as necessary


import io
import re
import sys


class Symbol(str):
    pass


def Sym(s, symbol_table={}):
    """Find or create unique Symbol entry for str s in symbol table."""
    if s not in symbol_table:
        symbol_table[s] = Symbol(s)
    return symbol_table[s]


(
    _quote,
    _if,
    _set,
    _define,
    _lambda,
    _begin,
    _definemacro,
) = map(Sym, "quote   if   set!  define   lambda   begin   define-macro".split())

_quasiquote, _unquote, _unquotesplicing = map(
    Sym, "quasiquote   unquote   unquote-splicing".split()
)


class Procedure:
    """A user-defined Scheme procedure."""

    def __init__(self, params, exp, env):
        self.params, self.exp, self.env = params, exp, env

    def __call__(self, *args):
        return eval(self.exp, Env(self.params, args, self.env))


################ parse, read, and user interaction


def parse(in_port):
    """Parse a program: read and expand/error-check it."""
    # Backwards compatibility: given a str, convert it to an InputPort
    if isinstance(in_port, str):
        in_port = InputPort(io.StringIO(in_port))
    return expand(read(in_port), toplevel=True)


eof_object = Symbol("#<eof-object>")  # Note: uninterned; can't be read


class InputPort:
    """An input port.

    Retains a line of chars.
    """

    tokenizer = r"""\s*(,@|[('`,)]|"(?:[\\].|[^\\"])*"|;.*|[^\s('"`,;)]*)(.*)"""

    def __init__(self, file):
        self.file = file
        self.line = ""

    def next_token(self):
        """Return the next token, reading new text into line buffer if
        needed."""
        while True:
            if self.line == "":
                self.line = self.file.readline()
            if self.line == "":
                return eof_object
            token, self.line = re.match(InputPort.tokenizer, self.line).groups()
            if token != "" and not token.startswith(";"):
                return token


def readchar(in_port):
    """Read the next character from an input port."""
    if in_port.line != "":
        ch, in_port.line = in_port.line[0], in_port.line[1:]
        return ch
    else:
        return in_port.file.read(1) or eof_object


def read(in_port):
    """Read a Scheme expression from an input port."""

    def read_ahead(token):
        if "(" == token:
            L = []
            cons = None
            while True:
                token = in_port.next_token()
                if token == ")":
                    return L
                if token == ".":
                    if len(L) > 1:
                        cons = [L.pop()]
                else:
                    ahead = read_ahead(token)
                    if cons:
                        cons.append(ahead)
                        ahead = cons
                        cons = None
                    L.append(ahead)
        elif ")" == token:
            raise SyntaxError("unexpected )")
        elif token in quotes:
            return [quotes[token], read(in_port)]
        elif token is eof_object:
            raise SyntaxError("unexpected EOF in list")
        else:
            return atom(token)

    # body of read:
    token1 = in_port.next_token()
    return eof_object if token1 is eof_object else read_ahead(token1)


quotes = {"'": _quote, "`": _quasiquote, ",": _unquote, ",@": _unquotesplicing}


def atom(token):
    """Numbers become numbers; #t and #f are booleans; "..." string; otherwise
    Symbol."""
    if token == "#t":
        return True
    elif token == "#f":
        return False
    elif token[0] == '"':
        return token[1:-1]
    try:
        return int(token)
    except ValueError:
        try:
            return float(token)
        except ValueError:
            try:
                return complex(token.replace("i", "j", 1))
            except ValueError:
                return Sym(token)


def to_string(x):
    """Convert a Python object back into a Lisp-readable string."""
    if x is True:
        return "#t"
    elif x is False:
        return "#f"
    elif isa(x, Symbol):
        return x
    elif isa(x, str):
        return repr(x)
    elif isa(x, list):
        return "(" + " ".join(map(to_string, x)) + ")"
    elif isa(x, complex):
        return str(x).replace("j", "i")
    else:
        return str(x)


def load(filename):
    """Eval every expression from a file."""
    repl(None, InputPort(open(filename)), None)


def repl(prompt="lispy> ", in_port=InputPort(sys.stdin), out=sys.stdout):
    """A prompt-read-eval-print loop."""
    sys.stderr.write("Lispy version 2.0\n")
    while True:
        try:
            if prompt:
                sys.stderr.write(prompt)
            x = parse(in_port)
            if x is eof_object:
                return
            val = eval(x)
            if val is not None and out:
                print(to_string(val), file=out)
        except Exception as e:
            print("%s: %s" % (type(e).__name__, e))


################ Environment class


class Env(dict):
    """An environment: a dict of {'var':val} pairs, with an outer Env."""

    def __init__(self, params=(), args=(), outer=None):
        # Bind paarm list to corresponding args, or single param to list of args
        self.outer = outer
        if isa(params, Symbol):
            self.update({params: list(args)})
        else:
            if len(args) != len(params):
                raise TypeError(
                    "expected %s, given %s, " % (to_string(params), to_string(args))
                )
            self.update(zip(params, args))

    def find(self, var):
        """Find the innermost Env where var appears."""
        if var in self:
            return self
        elif self.outer is None:
            raise LookupError(var)
        else:
            return self.outer.find(var)


def is_pair(x):
    return x != [] and isa(x, list)


def cons(x, y):
    return [x] + y


def callcc(proc):
    """Call proc with current continuation; escape only."""
    ball = RuntimeWarning("Sorry, can't continue this continuation any longer.")

    def throw(retval):
        ball.retval = retval
        raise ball

    try:
        return proc(throw)
    except RuntimeWarning as w:
        if w is ball:
            return ball.retval
        else:
            raise w


def add_globals(self):
    """Add some Scheme standard procedures."""
    import cmath
    import math
    import operator as op

    self.update(vars(math))
    self.update(vars(cmath))
    self.update(
        {
            "+": op.add,
            "-": op.sub,
            "*": op.mul,
            "/": op.truediv,
            "not": op.not_,
            ">": op.gt,
            "<": op.lt,
            ">=": op.ge,
            "<=": op.le,
            "=": op.eq,
            "equal?": op.eq,
            "eq?": op.is_,
            "length": len,
            "cons": cons,
            "car": lambda x: x[0],
            "cdr": lambda x: x[1:],
            "append": op.add,
            "list": lambda *x: list(x),
            "list?": lambda x: isa(x, list),
            "null?": lambda x: x == [],
            "symbol?": lambda x: isa(x, Symbol),
            "boolean?": lambda x: isa(x, bool),
            "pair?": is_pair,
            "port?": lambda x: isa(x, file),
            "apply": lambda proc, l: proc(*l),
            "eval": lambda x: eval(expand(x)),
            "load": lambda fn: load(fn),
            "call/cc": callcc,
            "open-input-file": open,
            "close-input-port": lambda p: p.file.close(),
            "open-output-file": lambda f: open(f, "w"),
            "close-output-port": lambda p: p.close(),
            "eof-object?": lambda x: x is eof_object,
            "read-char": readchar,
            "read": read,
            "write": lambda x, port=sys.stdout: port.write(to_string(x)),
            "display": lambda x, port=sys.stdout: port.write(
                x if isa(x, str) else to_string(x)
            ),
        }
    )
    return self


isa = isinstance

global_env = add_globals(Env())

################ eval (tail recursive)


def eval(x, env=global_env):
    """Evaluate an expression in an environment."""
    while True:
        if isa(x, Symbol):  # variable reference
            return env.find(x)[x]
        elif not isa(x, list):  # constant literal
            return x
        elif x[0] is _quote:  # (quote exp)
            (_, exp) = x
            return exp
        elif x[0] is _if:  # (if test conseq alt)
            (_, test, conseq, alt) = x
            x = conseq if eval(test, env) else alt
        elif x[0] is _set:  # (set! var exp)
            (_, var, exp) = x
            env.find(var)[var] = eval(exp, env)
            return None
        elif x[0] is _define:  # (define var exp)
            if len(x) == 3:
                (_, var, exp) = x
                env[var] = eval(exp, env)
            else:
                env[x[1]] = None
            return None
        elif x[0] is _lambda:  # (lambda (var*) exp)
            (_, vars, exp) = x
            return Procedure(vars, exp, env)
        elif x[0] is _begin:  # (begin exp+)
            for exp in x[1:-1]:
                eval(exp, env)
            x = x[-1]
        else:  # (proc exp*)
            exps = [eval(exp, env) for exp in x]
            proc = exps.pop(0)
            if isa(proc, Procedure):
                x = proc.exp
                env = Env(proc.params, exps, proc.env)
            else:
                return proc(*exps)


################ expand


def expand(x, toplevel=False):
    """Walk tree of x, making optimizations/fixes, and signaling
    SyntaxError."""
    # require(x, x!=[])                    # () => Error
    if x == []:
        return x
    if not isa(x, list):  # constant => unchanged
        return x
    elif x[0] is _quote:  # (quote exp)
        require(x, len(x) == 2)
        return x
    elif x[0] is _if:
        if len(x) == 3:
            x = x + [None]  # (if t c) => (if t c None)
        require(x, len(x) == 4)
        return list(map(expand, x))
    elif x[0] is _set:
        require(x, len(x) == 3)
        var = x[1]  # (set! non-var exp) => Error
        require(x, isa(var, Symbol), "can set! only a symbol")
        return [_set, var, expand(x[2])]
    elif x[0] is _define or x[0] is _definemacro:
        require(x, len(x) >= 2)
        _def, v, body = x[0], x[1], x[2:]
        if isa(v, list) and v:  # (define (f args) body)
            f, args = v[0], v[1:]  #  => (define f (lambda (args) body))
            return expand([_def, f, [_lambda, args] + body])
        else:
            require(x, len(x) in (2, 3))  # (define non-var/list exp) => Error
            if not isa(v, Symbol):
                return []
            exp = expand(x[2]) if len(x) == 3 else None
            if _def is _definemacro:
                require(x, toplevel, "define-macro only allowed at top level")
                proc = eval(exp)
                require(x, callable(proc), "macro must be a procedure")
                macro_table[v] = proc  # (define-macro v proc)
                return None  #  => None; add v:proc to macro_table
            return [_define, v, exp]
    elif x[0] is _begin:
        if len(x) == 1:
            return None  # (begin) => None
        else:
            return [expand(xi, toplevel) for xi in x]
    elif x[0] is _lambda:  # (lambda (x) e1 e2)
        require(x, len(x) >= 3)  #  => (lambda (x) (begin e1 e2))
        vars, body = x[1], x[2:]
        require(
            x,
            (isa(vars, list) and all(isa(v, Symbol) for v in vars))
            or isa(vars, Symbol),
            "illegal lambda argument list",
        )
        exp = body[0] if len(body) == 1 else [_begin] + body
        return [_lambda, vars, expand(exp)]
    elif x[0] is _quasiquote:  # `x => expand_quasiquote(x)
        require(x, len(x) == 2)
        return expand_quasiquote(x[1])
    elif isa(x[0], Symbol) and x[0] in macro_table:
        return expand(macro_table[x[0]](*x[1:]), toplevel)  # (m arg...)
    else:  #        => macroexpand if m isa macro
        return list(map(expand, x))  # (f arg...) => expand each


def require(x, predicate, msg="wrong length"):
    """Signal a syntax error if predicate is false."""
    if not predicate:
        raise SyntaxError(to_string(x) + ": " + msg)


_append, _cons, _let = map(Sym, "append cons let".split())


def expand_quasiquote(x):
    """Expand `x => 'x; `,x => x; `(,@x y) => (append x y)"""
    if not is_pair(x):
        return [_quote, x]
    require(x, x[0] is not _unquotesplicing, "can't splice here")
    if x[0] is _unquote:
        require(x, len(x) == 2)
        return x[1]
    elif is_pair(x[0]) and x[0][0] is _unquotesplicing:
        require(x[0], len(x[0]) == 2)
        return [_append, x[0][1], expand_quasiquote(x[1:])]
    else:
        return [_cons, expand_quasiquote(x[0]), expand_quasiquote(x[1:])]


def let(*args):
    args = list(args)
    x = cons(_let, args)
    require(x, len(args) > 1)
    bindings, body = args[0], args[1:]
    require(
        x,
        all(isa(b, list) and len(b) == 2 and isa(b[0], Symbol) for b in bindings),
        "illegal binding list",
    )
    vars, vals = zip(*bindings)
    return [[_lambda, list(vars)] + list(map(expand, body))] + list(map(expand, vals))


macro_table = {_let: let}  ## More macros can go here

eval(
    parse(
        """(begin

(define-macro and (lambda args
   (if (null? args) #t
       (if (= (length args) 1) (car args)
           `(if ,(car args) (and ,@(cdr args)) #f)))))

;; More macros can also go here

)"""
    )
)

if __name__ == "__main__":
    repl()



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .enable_instability_detector import enable_instability_detector
from .set_cfl_limit import set_cfl_limit
from .set_cfl_type import set_cfl_type
from .set_velocity_limit import set_velocity_limit
from .unstable_event_outer_iterations import unstable_event_outer_iterations
class instability_detector(Group):
    """
    'instability_detector' child.
    """

    fluent_name = "instability-detector"

    child_names = \
        ['enable_instability_detector', 'set_cfl_limit', 'set_cfl_type',
         'set_velocity_limit', 'unstable_event_outer_iterations']

    enable_instability_detector: enable_instability_detector = enable_instability_detector
    """
    enable_instability_detector child of instability_detector.
    """
    set_cfl_limit: set_cfl_limit = set_cfl_limit
    """
    set_cfl_limit child of instability_detector.
    """
    set_cfl_type: set_cfl_type = set_cfl_type
    """
    set_cfl_type child of instability_detector.
    """
    set_velocity_limit: set_velocity_limit = set_velocity_limit
    """
    set_velocity_limit child of instability_detector.
    """
    unstable_event_outer_iterations: unstable_event_outer_iterations = unstable_event_outer_iterations
    """
    unstable_event_outer_iterations child of instability_detector.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

class use_inherent_material_color(Boolean):
    """
    Use inherent material color for boundary zones.
    """

    fluent_name = "use-inherent-material-color?"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .coupled_solver import coupled_solver
from .segregated_solver import segregated_solver
from .density_based_solver import density_based_solver
class formulation(Group):
    """
    'formulation' child.
    """

    fluent_name = "formulation"

    child_names = \
        ['coupled_solver', 'segregated_solver', 'density_based_solver']

    coupled_solver: coupled_solver = coupled_solver
    """
    coupled_solver child of formulation.
    """
    segregated_solver: segregated_solver = segregated_solver
    """
    segregated_solver child of formulation.
    """
    density_based_solver: density_based_solver = density_based_solver
    """
    density_based_solver child of formulation.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

class crossover_tolerance(Real):
    """
    Set the fraction a particle is moved towards the cell center (0: not moved, 1: moved to cell center).
    """

    fluent_name = "crossover-tolerance"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .style import style
from .line_width import line_width
from .arrow_space import arrow_space
from .arrow_scale import arrow_scale
from .marker_size import marker_size
from .sphere_size import sphere_size
from .sphere_lod import sphere_lod
from .radius import radius
from .ribbon_settings import ribbon_settings
from .sphere_settings import sphere_settings
class style_attribute(Group):
    """
    'style_attribute' child.
    """

    fluent_name = "style-attribute"

    child_names = \
        ['style', 'line_width', 'arrow_space', 'arrow_scale', 'marker_size',
         'sphere_size', 'sphere_lod', 'radius', 'ribbon_settings',
         'sphere_settings']

    style: style = style
    """
    style child of style_attribute.
    """
    line_width: line_width = line_width
    """
    line_width child of style_attribute.
    """
    arrow_space: arrow_space = arrow_space
    """
    arrow_space child of style_attribute.
    """
    arrow_scale: arrow_scale = arrow_scale
    """
    arrow_scale child of style_attribute.
    """
    marker_size: marker_size = marker_size
    """
    marker_size child of style_attribute.
    """
    sphere_size: sphere_size = sphere_size
    """
    sphere_size child of style_attribute.
    """
    sphere_lod: sphere_lod = sphere_lod
    """
    sphere_lod child of style_attribute.
    """
    radius: radius = radius
    """
    radius child of style_attribute.
    """
    ribbon_settings: ribbon_settings = ribbon_settings
    """
    ribbon_settings child of style_attribute.
    """
    sphere_settings: sphere_settings = sphere_settings
    """
    sphere_settings child of style_attribute.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .trim_option import trim_option
from .update_frequency import update_frequency
from .damping_factor import damping_factor
from .thrust_coefficient import thrust_coefficient
from .x_moment_coefficient import x_moment_coefficient
from .y_moment_coefficient import y_moment_coefficient
class trimming(Group):
    """
    Menu to define rotor trimming set-up.
    
     - trim-option       : to define collective and cyclic pitches to trim, 
     - update-frequency  : the number of solver iterations that pitch angle will be updated each time, 
     - damping-factor    : relaxation factor for pitch angles, 
     - thrust-coef       : desired thrust coefficient to set pitch for
     - moment-coef-x     : desired x-moment coefficient to set pitch for, 
     - moment-coef-y     : desired y-moment coefficient to set pitch for, 
    
    For more details please consult the help option of the corresponding menu or TUI command.
    """

    fluent_name = "trimming"

    child_names = \
        ['trim_option', 'update_frequency', 'damping_factor',
         'thrust_coefficient', 'x_moment_coefficient',
         'y_moment_coefficient']

    trim_option: trim_option = trim_option
    """
    trim_option child of trimming.
    """
    update_frequency: update_frequency = update_frequency
    """
    update_frequency child of trimming.
    """
    damping_factor: damping_factor = damping_factor
    """
    damping_factor child of trimming.
    """
    thrust_coefficient: thrust_coefficient = thrust_coefficient
    """
    thrust_coefficient child of trimming.
    """
    x_moment_coefficient: x_moment_coefficient = x_moment_coefficient
    """
    x_moment_coefficient child of trimming.
    """
    y_moment_coefficient: y_moment_coefficient = y_moment_coefficient
    """
    y_moment_coefficient child of trimming.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .set_verbosity import set_verbosity
from .skewness_neighbor_coupling_1 import skewness_neighbor_coupling
from .hybrid_nita_settings import hybrid_nita_settings
class nita_expert_controls(Group):
    """
    Enter the nita expert controls menu.
    """

    fluent_name = "nita-expert-controls"

    child_names = \
        ['set_verbosity', 'skewness_neighbor_coupling',
         'hybrid_nita_settings']

    set_verbosity: set_verbosity = set_verbosity
    """
    set_verbosity child of nita_expert_controls.
    """
    skewness_neighbor_coupling: skewness_neighbor_coupling = skewness_neighbor_coupling
    """
    skewness_neighbor_coupling child of nita_expert_controls.
    """
    hybrid_nita_settings: hybrid_nita_settings = hybrid_nita_settings
    """
    hybrid_nita_settings child of nita_expert_controls.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .polar_pair_list_child import polar_pair_list_child

class polar_pair_list(ListObject[polar_pair_list_child]):
    """
    'polar_pair_list' child.
    """

    fluent_name = "polar-pair-list"

    child_object_type: polar_pair_list_child = polar_pair_list_child
    """
    child_object_type of polar_pair_list.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .report_type import report_type
from .old_props import old_props
class icing_child(Group):
    """
    'child_object_type' of icing.
    """

    fluent_name = "child-object-type"

    child_names = \
        ['report_type', 'old_props']

    report_type: report_type = report_type
    """
    report_type child of icing_child.
    """
    old_props: old_props = old_props
    """
    old_props child of icing_child.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

class number_of_coefficients(Integer):
    """
    Specify number of polynomial coefficients (polynomial order plus one).
    """

    fluent_name = "number-of-coefficients"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .enable import enable
class enable_strategy(Command):
    """
    Specify whether automatic initialization and case modification should be enabled.
    
    Parameters
    ----------
        enable : bool
            'enable' child.
    
    """

    fluent_name = "enable-strategy?"

    argument_names = \
        ['enable']

    enable: enable = enable
    """
    enable argument of enable_strategy.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .coefficient import coefficient
from .update_dissipation import update_dissipation
from .update_viscous import update_viscous
class multi_stage_child(Group):
    """
    'child_object_type' of multi_stage.
    """

    fluent_name = "child-object-type"

    child_names = \
        ['coefficient', 'update_dissipation', 'update_viscous']

    coefficient: coefficient = coefficient
    """
    coefficient child of multi_stage_child.
    """
    update_dissipation: update_dissipation = update_dissipation
    """
    update_dissipation child of multi_stage_child.
    """
    update_viscous: update_viscous = update_viscous
    """
    update_viscous child of multi_stage_child.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

class sbes_update_interval_k_omega(Integer):
    """
    Set an integer value how often the k and omega equations are updated in a transient SBES run.
    """

    fluent_name = "sbes-update-interval-k-omega"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

class interpolate_flow_viscosity(Boolean):
    """
    Enable/disable interpolation of flow laminar viscosity to the particle position.
    """

    fluent_name = "interpolate-flow-viscosity?"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .x import x
from .y import y
from .z import z
class u(Group):
    """
    'u' child.
    """

    fluent_name = "u"

    child_names = \
        ['x', 'y', 'z']

    x: x = x
    """
    x child of u.
    """
    y: y = y
    """
    y child of u.
    """
    z: z = z
    """
    z child of u.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .use import use
from .auto_1 import auto
from .threshold import threshold
from .interval import interval
class dynamic_mesh(Group):
    """
    Use load balancing for dynamic mesh?.
    """

    fluent_name = "dynamic-mesh"

    child_names = \
        ['use', 'auto', 'threshold', 'interval']

    use: use = use
    """
    use child of dynamic_mesh.
    """
    auto: auto = auto
    """
    auto child of dynamic_mesh.
    """
    threshold: threshold = threshold
    """
    threshold child of dynamic_mesh.
    """
    interval: interval = interval
    """
    interval child of dynamic_mesh.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .volumetric_species import volumetric_species
from .last_species import last_species
class species(Group):
    """
    'species' child.
    """

    fluent_name = "species"

    child_names = \
        ['volumetric_species', 'last_species']

    volumetric_species: volumetric_species = volumetric_species
    """
    volumetric_species child of species.
    """
    last_species: last_species = last_species
    """
    last_species child of species.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .law_1 import law_1
from .law_2 import law_2
from .law_3 import law_3
from .law_4 import law_4
from .law_5 import law_5
from .law_6 import law_6
from .law_7 import law_7
from .law_8 import law_8
from .law_9 import law_9
from .law_10 import law_10
from .switch import switch
class custom_laws(Group):
    """
    'custom_laws' child.
    """

    fluent_name = "custom-laws"

    child_names = \
        ['law_1', 'law_2', 'law_3', 'law_4', 'law_5', 'law_6', 'law_7',
         'law_8', 'law_9', 'law_10', 'switch']

    law_1: law_1 = law_1
    """
    law_1 child of custom_laws.
    """
    law_2: law_2 = law_2
    """
    law_2 child of custom_laws.
    """
    law_3: law_3 = law_3
    """
    law_3 child of custom_laws.
    """
    law_4: law_4 = law_4
    """
    law_4 child of custom_laws.
    """
    law_5: law_5 = law_5
    """
    law_5 child of custom_laws.
    """
    law_6: law_6 = law_6
    """
    law_6 child of custom_laws.
    """
    law_7: law_7 = law_7
    """
    law_7 child of custom_laws.
    """
    law_8: law_8 = law_8
    """
    law_8 child of custom_laws.
    """
    law_9: law_9 = law_9
    """
    law_9 child of custom_laws.
    """
    law_10: law_10 = law_10
    """
    law_10 child of custom_laws.
    """
    switch: switch = switch
    """
    switch child of custom_laws.
    """



"""Module containing class encapsulating Fluent connection and the Base
Session."""
import importlib
import json
import os
from typing import Any

from ansys.fluent.core.fluent_connection import _FluentConnection
from ansys.fluent.core.session_shared import (  # noqa: F401
    _CODEGEN_MSG_DATAMODEL,
    _CODEGEN_MSG_TUI,
)
from ansys.fluent.core.utils.logging import LOG

try:
    from ansys.fluent.core.solver.settings import root
except Exception:
    root = Any


def parse_server_info_file(filename: str):
    with open(filename, encoding="utf-8") as f:
        lines = f.readlines()
    ip_and_port = lines[0].strip().split(":")
    ip = ip_and_port[0]
    port = int(ip_and_port[1])
    password = lines[1].strip()
    return ip, port, password


def _get_datamodel_attributes(session, attribute: str):
    try:
        preferences_module = importlib.import_module(
            f"ansys.fluent.core.datamodel_{session.version}." + attribute
        )
        return preferences_module.Root(session._se_service, attribute, [])
    except (ImportError, ModuleNotFoundError):
        LOG.warning(_CODEGEN_MSG_DATAMODEL)


def _get_preferences(session):
    return _get_datamodel_attributes(session, "preferences")


def _get_solverworkflow(session):
    return _get_datamodel_attributes(session, "solverworkflow")


class _BaseSession:
    """Instantiates a Fluent connection.

    Attributes
    ----------
    scheme_eval: SchemeEval
        Instance of SchemeEval on which Fluent's scheme code can be
        executed.

    Methods
    -------
    create_from_server_info_file(
        server_info_filepath, cleanup_on_exit, start_transcript
        )
        Create a Session instance from server-info file

    exit()
        Close the Fluent connection and exit Fluent.
    """

    def __init__(self, fluent_connection: _FluentConnection):
        self.fluent_connection = fluent_connection
        self.scheme_eval = self.fluent_connection.scheme_eval
        self._uploader = None
        self._preferences = None
        self._solverworkflow = None

    @classmethod
    def create_from_server_info_file(
        cls,
        server_info_filepath: str,
        cleanup_on_exit: bool = True,
        start_transcript: bool = True,
    ):
        """Create a Session instance from server-info file.

        Parameters
        ----------
        server_info_filepath : str
            Path to server-info file written out by Fluent server
        cleanup_on_exit : bool, optional
            When True, the connected Fluent session will be shut down
            when PyFluent is exited or exit() is called on the session
            instance, by default True.
        start_transcript : bool, optional
            The Fluent transcript is started in the client only when
            start_transcript is True. It can be started and stopped
            subsequently via method calls on the Session object.
            Defaults to true.

        Returns
        -------
        Session
            Session instance
        """
        ip, port, password = parse_server_info_file(server_info_filepath)
        session = cls(
            fluent_connection=_FluentConnection(
                ip=ip,
                port=port,
                password=password,
                cleanup_on_exit=cleanup_on_exit,
                start_transcript=start_transcript,
            )
        )
        return session

    def execute_tui(self, command: str) -> None:
        """Executes a tui command."""
        self.fluent_connection.scheme_eval.scheme_eval(
            f'(tui-menu-execute {json.dumps(command)} "")'
        )

    def __enter__(self):
        """Close the Fluent connection and exit Fluent."""
        return self

    def __exit__(self, exc_type: Any, exc_val: Any, exc_tb: Any):
        self.fluent_connection.exit()

    def __getattr__(self, attr):
        if attr == "root":
            raise RuntimeError(
                "Please use the new structure where the settings objects can be accessed directly."
                " For example: 'solver.setup' or 'solver.solution'"
            )
        if attr == "solver":
            raise RuntimeError(
                "'Solver' is the parent object."
                " Please use the new structure, where: session.solver => solver."
            )
        return getattr(self.fluent_connection, attr)

    def __dir__(self):
        return sorted(
            set(
                list(self.__dict__.keys())
                + dir(type(self))
                + dir(self.fluent_connection)
            )
        )

    def upload(self, file_path: str, remote_file_name: str = None):
        """Uploads a file on the server."""
        if not self._uploader:
            self._uploader = _Uploader(self.fluent_connection._remote_instance)
        return self._uploader.upload(file_path, remote_file_name)

    def download(self, file_name: str, local_file_path: str = None):
        """Downloads a file from the server."""
        if not self._uploader:
            self._uploader = _Uploader(self.fluent_connection._remote_instance)
        return self._uploader.download(file_name, local_file_path)


class _Uploader:
    """Instantiates a file uploader and downloader to have a seamless file
    reading / writing in the cloud particularly in Ansys lab . Here we are
    exposing upload and download methods on session objects. These would be no-
    ops if PyPIM is not configured or not authorized with the appropriate
    service. This will be used for internal purpose only.

    Attributes
    ----------
    pim_instance: PIM instance
        Instance of PIM which supports upload server services.

    file_service: Client instance
        Instance of Client which supports upload and download methods.

    Methods
    -------
    upload(
        file_path, remote_file_name
        )
        Upload a file to the server.

    download(
        file_name, local_file_path
        )
        Download a file from the server.
    """

    def __init__(self, pim_instance):
        self.pim_instance = pim_instance
        self.file_service = None
        try:
            upload_server = self.pim_instance.services["http-simple-upload-server"]
        except (AttributeError, KeyError):
            pass
        else:
            from simple_upload_server.client import Client

            self.file_service = Client(
                token="token", url=upload_server.uri, headers=upload_server.headers
            )

    def upload(self, file_path: str, remote_file_name: str = None):
        """Uploads a file on the server."""
        if self.file_service:
            expanded_file_path = os.path.expandvars(file_path)
            upload_file_name = remote_file_name or os.path.basename(expanded_file_path)
            self.file_service.upload_file(expanded_file_path, upload_file_name)

    def download(self, file_name: str, local_file_path: str = None):
        """Downloads a file from the server."""
        if self.file_service:
            if self.file_service.file_exist(file_name):
                self.file_service.download_file(file_name, local_file_path)
            else:
                raise FileNotFoundError("Remote file does not exist.")



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .phase_24 import phase
from .geom_disable import geom_disable
from .geom_dir_spec import geom_dir_spec
from .geom_dir_x import geom_dir_x
from .geom_dir_y import geom_dir_y
from .geom_dir_z import geom_dir_z
from .geom_levels import geom_levels
from .geom_bgthread import geom_bgthread
from .d import d
from .q_dot import q_dot
from .material import material
from .thermal_bc import thermal_bc
from .t import t
from .q import q
from .h import h
from .tinf_1 import tinf
from .planar_conduction import planar_conduction
from .shell_conduction import shell_conduction
from .thin_wall import thin_wall
from .motion_bc import motion_bc
from .shear_bc import shear_bc
from .rough_bc import rough_bc
from .moving import moving
from .relative import relative
from .rotating import rotating
from .vmag import vmag
from .wall_translation import wall_translation
from .components_1 import components
from .velocity_1 import velocity
from .in_emiss import in_emiss
from .ex_emiss import ex_emiss
from .trad import trad
from .int_rad import int_rad
from .trad_internal import trad_internal
from .area_enhancement_factor import area_enhancement_factor
from .rough_option import rough_option
from .rough_nasa import rough_nasa
from .rough_shin_et_al import rough_shin_et_al
from .rough_data import rough_data
from .roughness_height import roughness_height
from .roughness_const import roughness_const
from .roughness_height_cp import roughness_height_cp
from .roughness_const_cp import roughness_const_cp
from .roughness_const_nasa import roughness_const_nasa
from .roughness_const_shin import roughness_const_shin
from .roughness_const_data import roughness_const_data
from .variable_roughness import variable_roughness
from .free_stream_velocity import free_stream_velocity
from .free_stream_temp import free_stream_temp
from .characteristic_length import characteristic_length
from .free_stream_temp_cp import free_stream_temp_cp
from .characteristic_length_cp import characteristic_length_cp
from .liquid_content import liquid_content
from .liquid_content_cp import liquid_content_cp
from .droplet_diameter import droplet_diameter
from .dpm_bc_type import dpm_bc_type
from .dpm_bc_collision_partner import dpm_bc_collision_partner
from .reinj_inj import reinj_inj
from .dpm_bc_norm_coeff import dpm_bc_norm_coeff
from .dpm_bc_tang_coeff import dpm_bc_tang_coeff
from .dpm_bc_frictn_coeff import dpm_bc_frictn_coeff
from .dpm_bc_udf import dpm_bc_udf
from .dpm_film_splash_nsamp import dpm_film_splash_nsamp
from .dpm_crit_temp_option import dpm_crit_temp_option
from .dpm_critical_temp_factor import dpm_critical_temp_factor
from .dpm_calibratable_temp import dpm_calibratable_temp
from .dpm_impingement_splashing_model import dpm_impingement_splashing_model
from .dpm_upper_deposition_limit_offset import dpm_upper_deposition_limit_offset
from .dpm_deposition_delta_t import dpm_deposition_delta_t
from .dpm_laplace_number_constant import dpm_laplace_number_constant
from .dpm_partial_evaporation_ratio import dpm_partial_evaporation_ratio
from .ra_roughness import ra_roughness
from .rz_roughness import rz_roughness
from .rq_roughness import rq_roughness
from .rsm_roughness import rsm_roughness
from .dpm_bc_erosion_generic import dpm_bc_erosion_generic
from .dpm_bc_erosion import dpm_bc_erosion
from .dpm_bc_erosion_c import dpm_bc_erosion_c
from .dpm_bc_erosion_n import dpm_bc_erosion_n
from .dpm_bc_erosion_finnie import dpm_bc_erosion_finnie
from .dpm_bc_erosion_finnie_k import dpm_bc_erosion_finnie_k
from .dpm_bc_erosion_finnie_vel_exp import dpm_bc_erosion_finnie_vel_exp
from .dpm_bc_erosion_finnie_max_erosion_angle import dpm_bc_erosion_finnie_max_erosion_angle
from .dpm_bc_erosion_mclaury import dpm_bc_erosion_mclaury
from .dpm_bc_erosion_mclaury_a import dpm_bc_erosion_mclaury_a
from .dpm_bc_erosion_mclaury_vel_exp import dpm_bc_erosion_mclaury_vel_exp
from .dpm_bc_erosion_mclaury_transition_angle import dpm_bc_erosion_mclaury_transition_angle
from .dpm_bc_erosion_mclaury_b import dpm_bc_erosion_mclaury_b
from .dpm_bc_erosion_mclaury_c import dpm_bc_erosion_mclaury_c
from .dpm_bc_erosion_mclaury_w import dpm_bc_erosion_mclaury_w
from .dpm_bc_erosion_mclaury_x import dpm_bc_erosion_mclaury_x
from .dpm_bc_erosion_mclaury_y import dpm_bc_erosion_mclaury_y
from .dpm_bc_erosion_oka import dpm_bc_erosion_oka
from .dpm_bc_erosion_oka_e90 import dpm_bc_erosion_oka_e90
from .dpm_bc_erosion_oka_hv import dpm_bc_erosion_oka_hv
from .dpm_bc_erosion_oka_n1 import dpm_bc_erosion_oka_n1
from .dpm_bc_erosion_oka_n2 import dpm_bc_erosion_oka_n2
from .dpm_bc_erosion_oka_k2 import dpm_bc_erosion_oka_k2
from .dpm_bc_erosion_oka_k3 import dpm_bc_erosion_oka_k3
from .dpm_bc_erosion_oka_dref import dpm_bc_erosion_oka_dref
from .dpm_bc_erosion_oka_vref import dpm_bc_erosion_oka_vref
from .dpm_bc_erosion_dnv import dpm_bc_erosion_dnv
from .dpm_bc_erosion_dnv_k import dpm_bc_erosion_dnv_k
from .dpm_bc_erosion_dnv_n import dpm_bc_erosion_dnv_n
from .dpm_bc_erosion_dnv_ductile import dpm_bc_erosion_dnv_ductile
from .dpm_bc_erosion_shear import dpm_bc_erosion_shear
from .dpm_bc_erosion_shear_v import dpm_bc_erosion_shear_v
from .dpm_bc_erosion_shear_c import dpm_bc_erosion_shear_c
from .dpm_bc_erosion_shear_packing_limit import dpm_bc_erosion_shear_packing_limit
from .dpm_bc_erosion_shielding import dpm_bc_erosion_shielding
from .dpm_wall_heat_exchange import dpm_wall_heat_exchange
from .dpm_film_condensation import dpm_film_condensation
from .dpm_film_bl_model import dpm_film_bl_model
from .dpm_particle_stripping import dpm_particle_stripping
from .dpm_critical_shear_stress import dpm_critical_shear_stress
from .dpm_film_separation_model import dpm_film_separation_model
from .dpm_critical_we_number import dpm_critical_we_number
from .dpm_film_separation_angle import dpm_film_separation_angle
from .dpm_allow_lwf_to_vof import dpm_allow_lwf_to_vof
from .dpm_allow_vof_to_lwf import dpm_allow_vof_to_lwf
from .dpm_initialize_lwf import dpm_initialize_lwf
from .dpm_initial_height import dpm_initial_height
from .film_velocity import film_velocity
from .dpm_initial_temperature import dpm_initial_temperature
from .dpm_initial_injection import dpm_initial_injection
from .film_parcel_surface_area_density import film_parcel_surface_area_density
from .minimum_number_of_parcels_per_face import minimum_number_of_parcels_per_face
from .band_in_emiss import band_in_emiss
from .radiation_bc import radiation_bc
from .mc_bsource_p import mc_bsource_p
from .mc_poldfun_p import mc_poldfun_p
from .polar_func_type import polar_func_type
from .mc_polar_expr import mc_polar_expr
from .polar_pair_list import polar_pair_list
from .pold_pair_list_rad import pold_pair_list_rad
from .radiation_direction import radiation_direction
from .coll_dtheta import coll_dtheta
from .coll_dphi import coll_dphi
from .band_q_irrad import band_q_irrad
from .band_q_irrad_diffuse import band_q_irrad_diffuse
from .band_diffuse_frac import band_diffuse_frac
from .radiating_s2s_surface import radiating_s2s_surface
from .critical_zone import critical_zone
from .fpsc import fpsc
from .parallel_collimated_beam import parallel_collimated_beam
from .solar_fluxes import solar_fluxes
from .solar_direction import solar_direction
from .solar_irradiation import solar_irradiation
from .v_transmissivity import v_transmissivity
from .ir_transmissivity import ir_transmissivity
from .v_opq_absorbtivity import v_opq_absorbtivity
from .ir_opq_absorbtivity import ir_opq_absorbtivity
from .v_st_absorbtivity import v_st_absorbtivity
from .ir_st_absorbtivity import ir_st_absorbtivity
from .d_st_absorbtivity import d_st_absorbtivity
from .d_transmissivity import d_transmissivity
from .fsi_interface import fsi_interface
from .react import react
from .partially_catalytic import partially_catalytic
from .partially_catalytic_material import partially_catalytic_material
from .partially_catalytic_recombination_coefficient_o import partially_catalytic_recombination_coefficient_o
from .partially_catalytic_recombination_coefficient_n import partially_catalytic_recombination_coefficient_n
from .partially_catalytic_recombination_model import partially_catalytic_recombination_model
from .species_spec import species_spec
from .mf import mf
from .elec_potential_type import elec_potential_type
from .potential_value import potential_value
from .elec_potential_jump import elec_potential_jump
from .elec_potential_resistance import elec_potential_resistance
from .dual_potential_type import dual_potential_type
from .dual_potential_value import dual_potential_value
from .echem_reaction import echem_reaction
from .elec_potential_mechs import elec_potential_mechs
from .faradaic_heat import faradaic_heat
from .li_ion_type import li_ion_type
from .li_ion_value import li_ion_value
from .x_displacement_type import x_displacement_type
from .x_displacement_value import x_displacement_value
from .y_displacement_type import y_displacement_type
from .y_displacement_value import y_displacement_value
from .z_displacement_type import z_displacement_type
from .z_displacement_value import z_displacement_value
from .per_dispx import per_dispx
from .per_dispy import per_dispy
from .per_dispz import per_dispz
from .per_imagx import per_imagx
from .per_imagy import per_imagy
from .per_imagz import per_imagz
from .freq import freq
from .amp import amp
from .nodal_diam import nodal_diam
from .pass_number import pass_number
from .fwd import fwd
from .aero import aero
from .cmplx import cmplx
from .norm import norm
from .method_2 import method
from .uds_bc import uds_bc
from .uds import uds
from .gtemp_bc import gtemp_bc
from .g_temperature import g_temperature
from .g_qflux import g_qflux
from .wall_restitution_coeff import wall_restitution_coeff
from .omega import omega
from .rotation_axis_origin import rotation_axis_origin
from .rotation_axis_direction import rotation_axis_direction
from .adhesion_angle import adhesion_angle
from .specified_shear import specified_shear
from .shear_stress import shear_stress
from .fslip import fslip
from .eslip import eslip
from .surf_tens_grad import surf_tens_grad
from .contact_resistance import contact_resistance
from .reaction_mechs_1 import reaction_mechs
from .surf_washcoat_factor import surf_washcoat_factor
from .initial_deposition_height import initial_deposition_height
from .solid_species_density import solid_species_density
from .ablation_select_model import ablation_select_model
from .ablation_vielle_a import ablation_vielle_a
from .ablation_vielle_n import ablation_vielle_n
from .ablation_flux import ablation_flux
from .ablation_surfacerxn_density import ablation_surfacerxn_density
from .ablation_species_mf import ablation_species_mf
from .specular_coeff import specular_coeff
from .mom_accom_coef import mom_accom_coef
from .therm_accom_coef import therm_accom_coef
from .eve_accom_coef import eve_accom_coef
from .film_wall import film_wall
from .film_wall_bc import film_wall_bc
from .film_height import film_height
from .flux_momentum import flux_momentum
from .film_relative_vel import film_relative_vel
from .film_bc_imp_press import film_bc_imp_press
from .film_temperature import film_temperature
from .film_scalar import film_scalar
from .film_source import film_source
from .film_h_src import film_h_src
from .momentum_source import momentum_source
from .film_t_src import film_t_src
from .film_s_src import film_s_src
from .film_phase_change import film_phase_change
from .film_phase_change_model import film_phase_change_model
from .film_cond_const import film_cond_const
from .film_vapo_const import film_vapo_const
from .film_cond_rate import film_cond_rate
from .film_vapo_rate import film_vapo_rate
from .film_momentum_coupling import film_momentum_coupling
from .film_splash_wall import film_splash_wall
from .film_boundary_separation import film_boundary_separation
from .film_impinge_model import film_impinge_model
from .film_splash_nparc import film_splash_nparc
from .film_crit_temp_factor import film_crit_temp_factor
from .film_roughness_ra import film_roughness_ra
from .film_roughness_rz import film_roughness_rz
from .film_upper_deposition_limit_offset import film_upper_deposition_limit_offset
from .film_deposition_delta_t import film_deposition_delta_t
from .film_laplace_number_constant import film_laplace_number_constant
from .film_partial_evap_ratio import film_partial_evap_ratio
from .film_contact_angle import film_contact_angle
from .film_contact_angle_mean import film_contact_angle_mean
from .film_contact_angle_rstd import film_contact_angle_rstd
from .film_contact_angle_beta import film_contact_angle_beta
from .film_vof_coupling_high import film_vof_coupling_high
from .film_vof_trans_high import film_vof_trans_high
from .film_vof_trans_high_relax import film_vof_trans_high_relax
from .film_vof_coupling_low import film_vof_coupling_low
from .film_vof_trans_low import film_vof_trans_low
from .film_vof_trans_low_relax import film_vof_trans_low_relax
from .caf import caf
from .thermal_stabilization import thermal_stabilization
from .scale_factor import scale_factor
from .stab_method import stab_method
from .fensapice_flow_bc_subtype import fensapice_flow_bc_subtype
from .fensapice_ice_icing_mode import fensapice_ice_icing_mode
from .fensapice_ice_hflux import fensapice_ice_hflux
from .fensapice_ice_hflux_1 import fensapice_ice_hflux_1
from .fensapice_drop_vwet import fensapice_drop_vwet
class wall_child(Group):
    """
    'child_object_type' of wall.
    """

    fluent_name = "child-object-type"

    child_names = \
        ['phase', 'geom_disable', 'geom_dir_spec', 'geom_dir_x', 'geom_dir_y',
         'geom_dir_z', 'geom_levels', 'geom_bgthread', 'd', 'q_dot',
         'material', 'thermal_bc', 't', 'q', 'h', 'tinf', 'planar_conduction',
         'shell_conduction', 'thin_wall', 'motion_bc', 'shear_bc', 'rough_bc',
         'moving', 'relative', 'rotating', 'vmag', 'wall_translation',
         'components', 'velocity', 'in_emiss', 'ex_emiss', 'trad', 'int_rad',
         'trad_internal', 'area_enhancement_factor', 'rough_option',
         'rough_nasa', 'rough_shin_et_al', 'rough_data', 'roughness_height',
         'roughness_const', 'roughness_height_cp', 'roughness_const_cp',
         'roughness_const_nasa', 'roughness_const_shin',
         'roughness_const_data', 'variable_roughness', 'free_stream_velocity',
         'free_stream_temp', 'characteristic_length', 'free_stream_temp_cp',
         'characteristic_length_cp', 'liquid_content', 'liquid_content_cp',
         'droplet_diameter', 'dpm_bc_type', 'dpm_bc_collision_partner',
         'reinj_inj', 'dpm_bc_norm_coeff', 'dpm_bc_tang_coeff',
         'dpm_bc_frictn_coeff', 'dpm_bc_udf', 'dpm_film_splash_nsamp',
         'dpm_crit_temp_option', 'dpm_critical_temp_factor',
         'dpm_calibratable_temp', 'dpm_impingement_splashing_model',
         'dpm_upper_deposition_limit_offset', 'dpm_deposition_delta_t',
         'dpm_laplace_number_constant', 'dpm_partial_evaporation_ratio',
         'ra_roughness', 'rz_roughness', 'rq_roughness', 'rsm_roughness',
         'dpm_bc_erosion_generic', 'dpm_bc_erosion', 'dpm_bc_erosion_c',
         'dpm_bc_erosion_n', 'dpm_bc_erosion_finnie',
         'dpm_bc_erosion_finnie_k', 'dpm_bc_erosion_finnie_vel_exp',
         'dpm_bc_erosion_finnie_max_erosion_angle', 'dpm_bc_erosion_mclaury',
         'dpm_bc_erosion_mclaury_a', 'dpm_bc_erosion_mclaury_vel_exp',
         'dpm_bc_erosion_mclaury_transition_angle',
         'dpm_bc_erosion_mclaury_b', 'dpm_bc_erosion_mclaury_c',
         'dpm_bc_erosion_mclaury_w', 'dpm_bc_erosion_mclaury_x',
         'dpm_bc_erosion_mclaury_y', 'dpm_bc_erosion_oka',
         'dpm_bc_erosion_oka_e90', 'dpm_bc_erosion_oka_hv',
         'dpm_bc_erosion_oka_n1', 'dpm_bc_erosion_oka_n2',
         'dpm_bc_erosion_oka_k2', 'dpm_bc_erosion_oka_k3',
         'dpm_bc_erosion_oka_dref', 'dpm_bc_erosion_oka_vref',
         'dpm_bc_erosion_dnv', 'dpm_bc_erosion_dnv_k', 'dpm_bc_erosion_dnv_n',
         'dpm_bc_erosion_dnv_ductile', 'dpm_bc_erosion_shear',
         'dpm_bc_erosion_shear_v', 'dpm_bc_erosion_shear_c',
         'dpm_bc_erosion_shear_packing_limit', 'dpm_bc_erosion_shielding',
         'dpm_wall_heat_exchange', 'dpm_film_condensation',
         'dpm_film_bl_model', 'dpm_particle_stripping',
         'dpm_critical_shear_stress', 'dpm_film_separation_model',
         'dpm_critical_we_number', 'dpm_film_separation_angle',
         'dpm_allow_lwf_to_vof', 'dpm_allow_vof_to_lwf', 'dpm_initialize_lwf',
         'dpm_initial_height', 'film_velocity', 'dpm_initial_temperature',
         'dpm_initial_injection', 'film_parcel_surface_area_density',
         'minimum_number_of_parcels_per_face', 'band_in_emiss',
         'radiation_bc', 'mc_bsource_p', 'mc_poldfun_p', 'polar_func_type',
         'mc_polar_expr', 'polar_pair_list', 'pold_pair_list_rad',
         'radiation_direction', 'coll_dtheta', 'coll_dphi', 'band_q_irrad',
         'band_q_irrad_diffuse', 'band_diffuse_frac', 'radiating_s2s_surface',
         'critical_zone', 'fpsc', 'parallel_collimated_beam', 'solar_fluxes',
         'solar_direction', 'solar_irradiation', 'v_transmissivity',
         'ir_transmissivity', 'v_opq_absorbtivity', 'ir_opq_absorbtivity',
         'v_st_absorbtivity', 'ir_st_absorbtivity', 'd_st_absorbtivity',
         'd_transmissivity', 'fsi_interface', 'react', 'partially_catalytic',
         'partially_catalytic_material',
         'partially_catalytic_recombination_coefficient_o',
         'partially_catalytic_recombination_coefficient_n',
         'partially_catalytic_recombination_model', 'species_spec', 'mf',
         'elec_potential_type', 'potential_value', 'elec_potential_jump',
         'elec_potential_resistance', 'dual_potential_type',
         'dual_potential_value', 'echem_reaction', 'elec_potential_mechs',
         'faradaic_heat', 'li_ion_type', 'li_ion_value',
         'x_displacement_type', 'x_displacement_value', 'y_displacement_type',
         'y_displacement_value', 'z_displacement_type',
         'z_displacement_value', 'per_dispx', 'per_dispy', 'per_dispz',
         'per_imagx', 'per_imagy', 'per_imagz', 'freq', 'amp', 'nodal_diam',
         'pass_number', 'fwd', 'aero', 'cmplx', 'norm', 'method', 'uds_bc',
         'uds', 'gtemp_bc', 'g_temperature', 'g_qflux',
         'wall_restitution_coeff', 'omega', 'rotation_axis_origin',
         'rotation_axis_direction', 'adhesion_angle', 'specified_shear',
         'shear_stress', 'fslip', 'eslip', 'surf_tens_grad',
         'contact_resistance', 'reaction_mechs', 'surf_washcoat_factor',
         'initial_deposition_height', 'solid_species_density',
         'ablation_select_model', 'ablation_vielle_a', 'ablation_vielle_n',
         'ablation_flux', 'ablation_surfacerxn_density',
         'ablation_species_mf', 'specular_coeff', 'mom_accom_coef',
         'therm_accom_coef', 'eve_accom_coef', 'film_wall', 'film_wall_bc',
         'film_height', 'flux_momentum', 'film_relative_vel',
         'film_bc_imp_press', 'film_temperature', 'film_scalar',
         'film_source', 'film_h_src', 'momentum_source', 'film_t_src',
         'film_s_src', 'film_phase_change', 'film_phase_change_model',
         'film_cond_const', 'film_vapo_const', 'film_cond_rate',
         'film_vapo_rate', 'film_momentum_coupling', 'film_splash_wall',
         'film_boundary_separation', 'film_impinge_model',
         'film_splash_nparc', 'film_crit_temp_factor', 'film_roughness_ra',
         'film_roughness_rz', 'film_upper_deposition_limit_offset',
         'film_deposition_delta_t', 'film_laplace_number_constant',
         'film_partial_evap_ratio', 'film_contact_angle',
         'film_contact_angle_mean', 'film_contact_angle_rstd',
         'film_contact_angle_beta', 'film_vof_coupling_high',
         'film_vof_trans_high', 'film_vof_trans_high_relax',
         'film_vof_coupling_low', 'film_vof_trans_low',
         'film_vof_trans_low_relax', 'caf', 'thermal_stabilization',
         'scale_factor', 'stab_method', 'fensapice_flow_bc_subtype',
         'fensapice_ice_icing_mode', 'fensapice_ice_hflux',
         'fensapice_ice_hflux_1', 'fensapice_drop_vwet']

    phase: phase = phase
    """
    phase child of wall_child.
    """
    geom_disable: geom_disable = geom_disable
    """
    geom_disable child of wall_child.
    """
    geom_dir_spec: geom_dir_spec = geom_dir_spec
    """
    geom_dir_spec child of wall_child.
    """
    geom_dir_x: geom_dir_x = geom_dir_x
    """
    geom_dir_x child of wall_child.
    """
    geom_dir_y: geom_dir_y = geom_dir_y
    """
    geom_dir_y child of wall_child.
    """
    geom_dir_z: geom_dir_z = geom_dir_z
    """
    geom_dir_z child of wall_child.
    """
    geom_levels: geom_levels = geom_levels
    """
    geom_levels child of wall_child.
    """
    geom_bgthread: geom_bgthread = geom_bgthread
    """
    geom_bgthread child of wall_child.
    """
    d: d = d
    """
    d child of wall_child.
    """
    q_dot: q_dot = q_dot
    """
    q_dot child of wall_child.
    """
    material: material = material
    """
    material child of wall_child.
    """
    thermal_bc: thermal_bc = thermal_bc
    """
    thermal_bc child of wall_child.
    """
    t: t = t
    """
    t child of wall_child.
    """
    q: q = q
    """
    q child of wall_child.
    """
    h: h = h
    """
    h child of wall_child.
    """
    tinf: tinf = tinf
    """
    tinf child of wall_child.
    """
    planar_conduction: planar_conduction = planar_conduction
    """
    planar_conduction child of wall_child.
    """
    shell_conduction: shell_conduction = shell_conduction
    """
    shell_conduction child of wall_child.
    """
    thin_wall: thin_wall = thin_wall
    """
    thin_wall child of wall_child.
    """
    motion_bc: motion_bc = motion_bc
    """
    motion_bc child of wall_child.
    """
    shear_bc: shear_bc = shear_bc
    """
    shear_bc child of wall_child.
    """
    rough_bc: rough_bc = rough_bc
    """
    rough_bc child of wall_child.
    """
    moving: moving = moving
    """
    moving child of wall_child.
    """
    relative: relative = relative
    """
    relative child of wall_child.
    """
    rotating: rotating = rotating
    """
    rotating child of wall_child.
    """
    vmag: vmag = vmag
    """
    vmag child of wall_child.
    """
    wall_translation: wall_translation = wall_translation
    """
    wall_translation child of wall_child.
    """
    components: components = components
    """
    components child of wall_child.
    """
    velocity: velocity = velocity
    """
    velocity child of wall_child.
    """
    in_emiss: in_emiss = in_emiss
    """
    in_emiss child of wall_child.
    """
    ex_emiss: ex_emiss = ex_emiss
    """
    ex_emiss child of wall_child.
    """
    trad: trad = trad
    """
    trad child of wall_child.
    """
    int_rad: int_rad = int_rad
    """
    int_rad child of wall_child.
    """
    trad_internal: trad_internal = trad_internal
    """
    trad_internal child of wall_child.
    """
    area_enhancement_factor: area_enhancement_factor = area_enhancement_factor
    """
    area_enhancement_factor child of wall_child.
    """
    rough_option: rough_option = rough_option
    """
    rough_option child of wall_child.
    """
    rough_nasa: rough_nasa = rough_nasa
    """
    rough_nasa child of wall_child.
    """
    rough_shin_et_al: rough_shin_et_al = rough_shin_et_al
    """
    rough_shin_et_al child of wall_child.
    """
    rough_data: rough_data = rough_data
    """
    rough_data child of wall_child.
    """
    roughness_height: roughness_height = roughness_height
    """
    roughness_height child of wall_child.
    """
    roughness_const: roughness_const = roughness_const
    """
    roughness_const child of wall_child.
    """
    roughness_height_cp: roughness_height_cp = roughness_height_cp
    """
    roughness_height_cp child of wall_child.
    """
    roughness_const_cp: roughness_const_cp = roughness_const_cp
    """
    roughness_const_cp child of wall_child.
    """
    roughness_const_nasa: roughness_const_nasa = roughness_const_nasa
    """
    roughness_const_nasa child of wall_child.
    """
    roughness_const_shin: roughness_const_shin = roughness_const_shin
    """
    roughness_const_shin child of wall_child.
    """
    roughness_const_data: roughness_const_data = roughness_const_data
    """
    roughness_const_data child of wall_child.
    """
    variable_roughness: variable_roughness = variable_roughness
    """
    variable_roughness child of wall_child.
    """
    free_stream_velocity: free_stream_velocity = free_stream_velocity
    """
    free_stream_velocity child of wall_child.
    """
    free_stream_temp: free_stream_temp = free_stream_temp
    """
    free_stream_temp child of wall_child.
    """
    characteristic_length: characteristic_length = characteristic_length
    """
    characteristic_length child of wall_child.
    """
    free_stream_temp_cp: free_stream_temp_cp = free_stream_temp_cp
    """
    free_stream_temp_cp child of wall_child.
    """
    characteristic_length_cp: characteristic_length_cp = characteristic_length_cp
    """
    characteristic_length_cp child of wall_child.
    """
    liquid_content: liquid_content = liquid_content
    """
    liquid_content child of wall_child.
    """
    liquid_content_cp: liquid_content_cp = liquid_content_cp
    """
    liquid_content_cp child of wall_child.
    """
    droplet_diameter: droplet_diameter = droplet_diameter
    """
    droplet_diameter child of wall_child.
    """
    dpm_bc_type: dpm_bc_type = dpm_bc_type
    """
    dpm_bc_type child of wall_child.
    """
    dpm_bc_collision_partner: dpm_bc_collision_partner = dpm_bc_collision_partner
    """
    dpm_bc_collision_partner child of wall_child.
    """
    reinj_inj: reinj_inj = reinj_inj
    """
    reinj_inj child of wall_child.
    """
    dpm_bc_norm_coeff: dpm_bc_norm_coeff = dpm_bc_norm_coeff
    """
    dpm_bc_norm_coeff child of wall_child.
    """
    dpm_bc_tang_coeff: dpm_bc_tang_coeff = dpm_bc_tang_coeff
    """
    dpm_bc_tang_coeff child of wall_child.
    """
    dpm_bc_frictn_coeff: dpm_bc_frictn_coeff = dpm_bc_frictn_coeff
    """
    dpm_bc_frictn_coeff child of wall_child.
    """
    dpm_bc_udf: dpm_bc_udf = dpm_bc_udf
    """
    dpm_bc_udf child of wall_child.
    """
    dpm_film_splash_nsamp: dpm_film_splash_nsamp = dpm_film_splash_nsamp
    """
    dpm_film_splash_nsamp child of wall_child.
    """
    dpm_crit_temp_option: dpm_crit_temp_option = dpm_crit_temp_option
    """
    dpm_crit_temp_option child of wall_child.
    """
    dpm_critical_temp_factor: dpm_critical_temp_factor = dpm_critical_temp_factor
    """
    dpm_critical_temp_factor child of wall_child.
    """
    dpm_calibratable_temp: dpm_calibratable_temp = dpm_calibratable_temp
    """
    dpm_calibratable_temp child of wall_child.
    """
    dpm_impingement_splashing_model: dpm_impingement_splashing_model = dpm_impingement_splashing_model
    """
    dpm_impingement_splashing_model child of wall_child.
    """
    dpm_upper_deposition_limit_offset: dpm_upper_deposition_limit_offset = dpm_upper_deposition_limit_offset
    """
    dpm_upper_deposition_limit_offset child of wall_child.
    """
    dpm_deposition_delta_t: dpm_deposition_delta_t = dpm_deposition_delta_t
    """
    dpm_deposition_delta_t child of wall_child.
    """
    dpm_laplace_number_constant: dpm_laplace_number_constant = dpm_laplace_number_constant
    """
    dpm_laplace_number_constant child of wall_child.
    """
    dpm_partial_evaporation_ratio: dpm_partial_evaporation_ratio = dpm_partial_evaporation_ratio
    """
    dpm_partial_evaporation_ratio child of wall_child.
    """
    ra_roughness: ra_roughness = ra_roughness
    """
    ra_roughness child of wall_child.
    """
    rz_roughness: rz_roughness = rz_roughness
    """
    rz_roughness child of wall_child.
    """
    rq_roughness: rq_roughness = rq_roughness
    """
    rq_roughness child of wall_child.
    """
    rsm_roughness: rsm_roughness = rsm_roughness
    """
    rsm_roughness child of wall_child.
    """
    dpm_bc_erosion_generic: dpm_bc_erosion_generic = dpm_bc_erosion_generic
    """
    dpm_bc_erosion_generic child of wall_child.
    """
    dpm_bc_erosion: dpm_bc_erosion = dpm_bc_erosion
    """
    dpm_bc_erosion child of wall_child.
    """
    dpm_bc_erosion_c: dpm_bc_erosion_c = dpm_bc_erosion_c
    """
    dpm_bc_erosion_c child of wall_child.
    """
    dpm_bc_erosion_n: dpm_bc_erosion_n = dpm_bc_erosion_n
    """
    dpm_bc_erosion_n child of wall_child.
    """
    dpm_bc_erosion_finnie: dpm_bc_erosion_finnie = dpm_bc_erosion_finnie
    """
    dpm_bc_erosion_finnie child of wall_child.
    """
    dpm_bc_erosion_finnie_k: dpm_bc_erosion_finnie_k = dpm_bc_erosion_finnie_k
    """
    dpm_bc_erosion_finnie_k child of wall_child.
    """
    dpm_bc_erosion_finnie_vel_exp: dpm_bc_erosion_finnie_vel_exp = dpm_bc_erosion_finnie_vel_exp
    """
    dpm_bc_erosion_finnie_vel_exp child of wall_child.
    """
    dpm_bc_erosion_finnie_max_erosion_angle: dpm_bc_erosion_finnie_max_erosion_angle = dpm_bc_erosion_finnie_max_erosion_angle
    """
    dpm_bc_erosion_finnie_max_erosion_angle child of wall_child.
    """
    dpm_bc_erosion_mclaury: dpm_bc_erosion_mclaury = dpm_bc_erosion_mclaury
    """
    dpm_bc_erosion_mclaury child of wall_child.
    """
    dpm_bc_erosion_mclaury_a: dpm_bc_erosion_mclaury_a = dpm_bc_erosion_mclaury_a
    """
    dpm_bc_erosion_mclaury_a child of wall_child.
    """
    dpm_bc_erosion_mclaury_vel_exp: dpm_bc_erosion_mclaury_vel_exp = dpm_bc_erosion_mclaury_vel_exp
    """
    dpm_bc_erosion_mclaury_vel_exp child of wall_child.
    """
    dpm_bc_erosion_mclaury_transition_angle: dpm_bc_erosion_mclaury_transition_angle = dpm_bc_erosion_mclaury_transition_angle
    """
    dpm_bc_erosion_mclaury_transition_angle child of wall_child.
    """
    dpm_bc_erosion_mclaury_b: dpm_bc_erosion_mclaury_b = dpm_bc_erosion_mclaury_b
    """
    dpm_bc_erosion_mclaury_b child of wall_child.
    """
    dpm_bc_erosion_mclaury_c: dpm_bc_erosion_mclaury_c = dpm_bc_erosion_mclaury_c
    """
    dpm_bc_erosion_mclaury_c child of wall_child.
    """
    dpm_bc_erosion_mclaury_w: dpm_bc_erosion_mclaury_w = dpm_bc_erosion_mclaury_w
    """
    dpm_bc_erosion_mclaury_w child of wall_child.
    """
    dpm_bc_erosion_mclaury_x: dpm_bc_erosion_mclaury_x = dpm_bc_erosion_mclaury_x
    """
    dpm_bc_erosion_mclaury_x child of wall_child.
    """
    dpm_bc_erosion_mclaury_y: dpm_bc_erosion_mclaury_y = dpm_bc_erosion_mclaury_y
    """
    dpm_bc_erosion_mclaury_y child of wall_child.
    """
    dpm_bc_erosion_oka: dpm_bc_erosion_oka = dpm_bc_erosion_oka
    """
    dpm_bc_erosion_oka child of wall_child.
    """
    dpm_bc_erosion_oka_e90: dpm_bc_erosion_oka_e90 = dpm_bc_erosion_oka_e90
    """
    dpm_bc_erosion_oka_e90 child of wall_child.
    """
    dpm_bc_erosion_oka_hv: dpm_bc_erosion_oka_hv = dpm_bc_erosion_oka_hv
    """
    dpm_bc_erosion_oka_hv child of wall_child.
    """
    dpm_bc_erosion_oka_n1: dpm_bc_erosion_oka_n1 = dpm_bc_erosion_oka_n1
    """
    dpm_bc_erosion_oka_n1 child of wall_child.
    """
    dpm_bc_erosion_oka_n2: dpm_bc_erosion_oka_n2 = dpm_bc_erosion_oka_n2
    """
    dpm_bc_erosion_oka_n2 child of wall_child.
    """
    dpm_bc_erosion_oka_k2: dpm_bc_erosion_oka_k2 = dpm_bc_erosion_oka_k2
    """
    dpm_bc_erosion_oka_k2 child of wall_child.
    """
    dpm_bc_erosion_oka_k3: dpm_bc_erosion_oka_k3 = dpm_bc_erosion_oka_k3
    """
    dpm_bc_erosion_oka_k3 child of wall_child.
    """
    dpm_bc_erosion_oka_dref: dpm_bc_erosion_oka_dref = dpm_bc_erosion_oka_dref
    """
    dpm_bc_erosion_oka_dref child of wall_child.
    """
    dpm_bc_erosion_oka_vref: dpm_bc_erosion_oka_vref = dpm_bc_erosion_oka_vref
    """
    dpm_bc_erosion_oka_vref child of wall_child.
    """
    dpm_bc_erosion_dnv: dpm_bc_erosion_dnv = dpm_bc_erosion_dnv
    """
    dpm_bc_erosion_dnv child of wall_child.
    """
    dpm_bc_erosion_dnv_k: dpm_bc_erosion_dnv_k = dpm_bc_erosion_dnv_k
    """
    dpm_bc_erosion_dnv_k child of wall_child.
    """
    dpm_bc_erosion_dnv_n: dpm_bc_erosion_dnv_n = dpm_bc_erosion_dnv_n
    """
    dpm_bc_erosion_dnv_n child of wall_child.
    """
    dpm_bc_erosion_dnv_ductile: dpm_bc_erosion_dnv_ductile = dpm_bc_erosion_dnv_ductile
    """
    dpm_bc_erosion_dnv_ductile child of wall_child.
    """
    dpm_bc_erosion_shear: dpm_bc_erosion_shear = dpm_bc_erosion_shear
    """
    dpm_bc_erosion_shear child of wall_child.
    """
    dpm_bc_erosion_shear_v: dpm_bc_erosion_shear_v = dpm_bc_erosion_shear_v
    """
    dpm_bc_erosion_shear_v child of wall_child.
    """
    dpm_bc_erosion_shear_c: dpm_bc_erosion_shear_c = dpm_bc_erosion_shear_c
    """
    dpm_bc_erosion_shear_c child of wall_child.
    """
    dpm_bc_erosion_shear_packing_limit: dpm_bc_erosion_shear_packing_limit = dpm_bc_erosion_shear_packing_limit
    """
    dpm_bc_erosion_shear_packing_limit child of wall_child.
    """
    dpm_bc_erosion_shielding: dpm_bc_erosion_shielding = dpm_bc_erosion_shielding
    """
    dpm_bc_erosion_shielding child of wall_child.
    """
    dpm_wall_heat_exchange: dpm_wall_heat_exchange = dpm_wall_heat_exchange
    """
    dpm_wall_heat_exchange child of wall_child.
    """
    dpm_film_condensation: dpm_film_condensation = dpm_film_condensation
    """
    dpm_film_condensation child of wall_child.
    """
    dpm_film_bl_model: dpm_film_bl_model = dpm_film_bl_model
    """
    dpm_film_bl_model child of wall_child.
    """
    dpm_particle_stripping: dpm_particle_stripping = dpm_particle_stripping
    """
    dpm_particle_stripping child of wall_child.
    """
    dpm_critical_shear_stress: dpm_critical_shear_stress = dpm_critical_shear_stress
    """
    dpm_critical_shear_stress child of wall_child.
    """
    dpm_film_separation_model: dpm_film_separation_model = dpm_film_separation_model
    """
    dpm_film_separation_model child of wall_child.
    """
    dpm_critical_we_number: dpm_critical_we_number = dpm_critical_we_number
    """
    dpm_critical_we_number child of wall_child.
    """
    dpm_film_separation_angle: dpm_film_separation_angle = dpm_film_separation_angle
    """
    dpm_film_separation_angle child of wall_child.
    """
    dpm_allow_lwf_to_vof: dpm_allow_lwf_to_vof = dpm_allow_lwf_to_vof
    """
    dpm_allow_lwf_to_vof child of wall_child.
    """
    dpm_allow_vof_to_lwf: dpm_allow_vof_to_lwf = dpm_allow_vof_to_lwf
    """
    dpm_allow_vof_to_lwf child of wall_child.
    """
    dpm_initialize_lwf: dpm_initialize_lwf = dpm_initialize_lwf
    """
    dpm_initialize_lwf child of wall_child.
    """
    dpm_initial_height: dpm_initial_height = dpm_initial_height
    """
    dpm_initial_height child of wall_child.
    """
    film_velocity: film_velocity = film_velocity
    """
    film_velocity child of wall_child.
    """
    dpm_initial_temperature: dpm_initial_temperature = dpm_initial_temperature
    """
    dpm_initial_temperature child of wall_child.
    """
    dpm_initial_injection: dpm_initial_injection = dpm_initial_injection
    """
    dpm_initial_injection child of wall_child.
    """
    film_parcel_surface_area_density: film_parcel_surface_area_density = film_parcel_surface_area_density
    """
    film_parcel_surface_area_density child of wall_child.
    """
    minimum_number_of_parcels_per_face: minimum_number_of_parcels_per_face = minimum_number_of_parcels_per_face
    """
    minimum_number_of_parcels_per_face child of wall_child.
    """
    band_in_emiss: band_in_emiss = band_in_emiss
    """
    band_in_emiss child of wall_child.
    """
    radiation_bc: radiation_bc = radiation_bc
    """
    radiation_bc child of wall_child.
    """
    mc_bsource_p: mc_bsource_p = mc_bsource_p
    """
    mc_bsource_p child of wall_child.
    """
    mc_poldfun_p: mc_poldfun_p = mc_poldfun_p
    """
    mc_poldfun_p child of wall_child.
    """
    polar_func_type: polar_func_type = polar_func_type
    """
    polar_func_type child of wall_child.
    """
    mc_polar_expr: mc_polar_expr = mc_polar_expr
    """
    mc_polar_expr child of wall_child.
    """
    polar_pair_list: polar_pair_list = polar_pair_list
    """
    polar_pair_list child of wall_child.
    """
    pold_pair_list_rad: pold_pair_list_rad = pold_pair_list_rad
    """
    pold_pair_list_rad child of wall_child.
    """
    radiation_direction: radiation_direction = radiation_direction
    """
    radiation_direction child of wall_child.
    """
    coll_dtheta: coll_dtheta = coll_dtheta
    """
    coll_dtheta child of wall_child.
    """
    coll_dphi: coll_dphi = coll_dphi
    """
    coll_dphi child of wall_child.
    """
    band_q_irrad: band_q_irrad = band_q_irrad
    """
    band_q_irrad child of wall_child.
    """
    band_q_irrad_diffuse: band_q_irrad_diffuse = band_q_irrad_diffuse
    """
    band_q_irrad_diffuse child of wall_child.
    """
    band_diffuse_frac: band_diffuse_frac = band_diffuse_frac
    """
    band_diffuse_frac child of wall_child.
    """
    radiating_s2s_surface: radiating_s2s_surface = radiating_s2s_surface
    """
    radiating_s2s_surface child of wall_child.
    """
    critical_zone: critical_zone = critical_zone
    """
    critical_zone child of wall_child.
    """
    fpsc: fpsc = fpsc
    """
    fpsc child of wall_child.
    """
    parallel_collimated_beam: parallel_collimated_beam = parallel_collimated_beam
    """
    parallel_collimated_beam child of wall_child.
    """
    solar_fluxes: solar_fluxes = solar_fluxes
    """
    solar_fluxes child of wall_child.
    """
    solar_direction: solar_direction = solar_direction
    """
    solar_direction child of wall_child.
    """
    solar_irradiation: solar_irradiation = solar_irradiation
    """
    solar_irradiation child of wall_child.
    """
    v_transmissivity: v_transmissivity = v_transmissivity
    """
    v_transmissivity child of wall_child.
    """
    ir_transmissivity: ir_transmissivity = ir_transmissivity
    """
    ir_transmissivity child of wall_child.
    """
    v_opq_absorbtivity: v_opq_absorbtivity = v_opq_absorbtivity
    """
    v_opq_absorbtivity child of wall_child.
    """
    ir_opq_absorbtivity: ir_opq_absorbtivity = ir_opq_absorbtivity
    """
    ir_opq_absorbtivity child of wall_child.
    """
    v_st_absorbtivity: v_st_absorbtivity = v_st_absorbtivity
    """
    v_st_absorbtivity child of wall_child.
    """
    ir_st_absorbtivity: ir_st_absorbtivity = ir_st_absorbtivity
    """
    ir_st_absorbtivity child of wall_child.
    """
    d_st_absorbtivity: d_st_absorbtivity = d_st_absorbtivity
    """
    d_st_absorbtivity child of wall_child.
    """
    d_transmissivity: d_transmissivity = d_transmissivity
    """
    d_transmissivity child of wall_child.
    """
    fsi_interface: fsi_interface = fsi_interface
    """
    fsi_interface child of wall_child.
    """
    react: react = react
    """
    react child of wall_child.
    """
    partially_catalytic: partially_catalytic = partially_catalytic
    """
    partially_catalytic child of wall_child.
    """
    partially_catalytic_material: partially_catalytic_material = partially_catalytic_material
    """
    partially_catalytic_material child of wall_child.
    """
    partially_catalytic_recombination_coefficient_o: partially_catalytic_recombination_coefficient_o = partially_catalytic_recombination_coefficient_o
    """
    partially_catalytic_recombination_coefficient_o child of wall_child.
    """
    partially_catalytic_recombination_coefficient_n: partially_catalytic_recombination_coefficient_n = partially_catalytic_recombination_coefficient_n
    """
    partially_catalytic_recombination_coefficient_n child of wall_child.
    """
    partially_catalytic_recombination_model: partially_catalytic_recombination_model = partially_catalytic_recombination_model
    """
    partially_catalytic_recombination_model child of wall_child.
    """
    species_spec: species_spec = species_spec
    """
    species_spec child of wall_child.
    """
    mf: mf = mf
    """
    mf child of wall_child.
    """
    elec_potential_type: elec_potential_type = elec_potential_type
    """
    elec_potential_type child of wall_child.
    """
    potential_value: potential_value = potential_value
    """
    potential_value child of wall_child.
    """
    elec_potential_jump: elec_potential_jump = elec_potential_jump
    """
    elec_potential_jump child of wall_child.
    """
    elec_potential_resistance: elec_potential_resistance = elec_potential_resistance
    """
    elec_potential_resistance child of wall_child.
    """
    dual_potential_type: dual_potential_type = dual_potential_type
    """
    dual_potential_type child of wall_child.
    """
    dual_potential_value: dual_potential_value = dual_potential_value
    """
    dual_potential_value child of wall_child.
    """
    echem_reaction: echem_reaction = echem_reaction
    """
    echem_reaction child of wall_child.
    """
    elec_potential_mechs: elec_potential_mechs = elec_potential_mechs
    """
    elec_potential_mechs child of wall_child.
    """
    faradaic_heat: faradaic_heat = faradaic_heat
    """
    faradaic_heat child of wall_child.
    """
    li_ion_type: li_ion_type = li_ion_type
    """
    li_ion_type child of wall_child.
    """
    li_ion_value: li_ion_value = li_ion_value
    """
    li_ion_value child of wall_child.
    """
    x_displacement_type: x_displacement_type = x_displacement_type
    """
    x_displacement_type child of wall_child.
    """
    x_displacement_value: x_displacement_value = x_displacement_value
    """
    x_displacement_value child of wall_child.
    """
    y_displacement_type: y_displacement_type = y_displacement_type
    """
    y_displacement_type child of wall_child.
    """
    y_displacement_value: y_displacement_value = y_displacement_value
    """
    y_displacement_value child of wall_child.
    """
    z_displacement_type: z_displacement_type = z_displacement_type
    """
    z_displacement_type child of wall_child.
    """
    z_displacement_value: z_displacement_value = z_displacement_value
    """
    z_displacement_value child of wall_child.
    """
    per_dispx: per_dispx = per_dispx
    """
    per_dispx child of wall_child.
    """
    per_dispy: per_dispy = per_dispy
    """
    per_dispy child of wall_child.
    """
    per_dispz: per_dispz = per_dispz
    """
    per_dispz child of wall_child.
    """
    per_imagx: per_imagx = per_imagx
    """
    per_imagx child of wall_child.
    """
    per_imagy: per_imagy = per_imagy
    """
    per_imagy child of wall_child.
    """
    per_imagz: per_imagz = per_imagz
    """
    per_imagz child of wall_child.
    """
    freq: freq = freq
    """
    freq child of wall_child.
    """
    amp: amp = amp
    """
    amp child of wall_child.
    """
    nodal_diam: nodal_diam = nodal_diam
    """
    nodal_diam child of wall_child.
    """
    pass_number: pass_number = pass_number
    """
    pass_number child of wall_child.
    """
    fwd: fwd = fwd
    """
    fwd child of wall_child.
    """
    aero: aero = aero
    """
    aero child of wall_child.
    """
    cmplx: cmplx = cmplx
    """
    cmplx child of wall_child.
    """
    norm: norm = norm
    """
    norm child of wall_child.
    """
    method: method = method
    """
    method child of wall_child.
    """
    uds_bc: uds_bc = uds_bc
    """
    uds_bc child of wall_child.
    """
    uds: uds = uds
    """
    uds child of wall_child.
    """
    gtemp_bc: gtemp_bc = gtemp_bc
    """
    gtemp_bc child of wall_child.
    """
    g_temperature: g_temperature = g_temperature
    """
    g_temperature child of wall_child.
    """
    g_qflux: g_qflux = g_qflux
    """
    g_qflux child of wall_child.
    """
    wall_restitution_coeff: wall_restitution_coeff = wall_restitution_coeff
    """
    wall_restitution_coeff child of wall_child.
    """
    omega: omega = omega
    """
    omega child of wall_child.
    """
    rotation_axis_origin: rotation_axis_origin = rotation_axis_origin
    """
    rotation_axis_origin child of wall_child.
    """
    rotation_axis_direction: rotation_axis_direction = rotation_axis_direction
    """
    rotation_axis_direction child of wall_child.
    """
    adhesion_angle: adhesion_angle = adhesion_angle
    """
    adhesion_angle child of wall_child.
    """
    specified_shear: specified_shear = specified_shear
    """
    specified_shear child of wall_child.
    """
    shear_stress: shear_stress = shear_stress
    """
    shear_stress child of wall_child.
    """
    fslip: fslip = fslip
    """
    fslip child of wall_child.
    """
    eslip: eslip = eslip
    """
    eslip child of wall_child.
    """
    surf_tens_grad: surf_tens_grad = surf_tens_grad
    """
    surf_tens_grad child of wall_child.
    """
    contact_resistance: contact_resistance = contact_resistance
    """
    contact_resistance child of wall_child.
    """
    reaction_mechs: reaction_mechs = reaction_mechs
    """
    reaction_mechs child of wall_child.
    """
    surf_washcoat_factor: surf_washcoat_factor = surf_washcoat_factor
    """
    surf_washcoat_factor child of wall_child.
    """
    initial_deposition_height: initial_deposition_height = initial_deposition_height
    """
    initial_deposition_height child of wall_child.
    """
    solid_species_density: solid_species_density = solid_species_density
    """
    solid_species_density child of wall_child.
    """
    ablation_select_model: ablation_select_model = ablation_select_model
    """
    ablation_select_model child of wall_child.
    """
    ablation_vielle_a: ablation_vielle_a = ablation_vielle_a
    """
    ablation_vielle_a child of wall_child.
    """
    ablation_vielle_n: ablation_vielle_n = ablation_vielle_n
    """
    ablation_vielle_n child of wall_child.
    """
    ablation_flux: ablation_flux = ablation_flux
    """
    ablation_flux child of wall_child.
    """
    ablation_surfacerxn_density: ablation_surfacerxn_density = ablation_surfacerxn_density
    """
    ablation_surfacerxn_density child of wall_child.
    """
    ablation_species_mf: ablation_species_mf = ablation_species_mf
    """
    ablation_species_mf child of wall_child.
    """
    specular_coeff: specular_coeff = specular_coeff
    """
    specular_coeff child of wall_child.
    """
    mom_accom_coef: mom_accom_coef = mom_accom_coef
    """
    mom_accom_coef child of wall_child.
    """
    therm_accom_coef: therm_accom_coef = therm_accom_coef
    """
    therm_accom_coef child of wall_child.
    """
    eve_accom_coef: eve_accom_coef = eve_accom_coef
    """
    eve_accom_coef child of wall_child.
    """
    film_wall: film_wall = film_wall
    """
    film_wall child of wall_child.
    """
    film_wall_bc: film_wall_bc = film_wall_bc
    """
    film_wall_bc child of wall_child.
    """
    film_height: film_height = film_height
    """
    film_height child of wall_child.
    """
    flux_momentum: flux_momentum = flux_momentum
    """
    flux_momentum child of wall_child.
    """
    film_relative_vel: film_relative_vel = film_relative_vel
    """
    film_relative_vel child of wall_child.
    """
    film_bc_imp_press: film_bc_imp_press = film_bc_imp_press
    """
    film_bc_imp_press child of wall_child.
    """
    film_temperature: film_temperature = film_temperature
    """
    film_temperature child of wall_child.
    """
    film_scalar: film_scalar = film_scalar
    """
    film_scalar child of wall_child.
    """
    film_source: film_source = film_source
    """
    film_source child of wall_child.
    """
    film_h_src: film_h_src = film_h_src
    """
    film_h_src child of wall_child.
    """
    momentum_source: momentum_source = momentum_source
    """
    momentum_source child of wall_child.
    """
    film_t_src: film_t_src = film_t_src
    """
    film_t_src child of wall_child.
    """
    film_s_src: film_s_src = film_s_src
    """
    film_s_src child of wall_child.
    """
    film_phase_change: film_phase_change = film_phase_change
    """
    film_phase_change child of wall_child.
    """
    film_phase_change_model: film_phase_change_model = film_phase_change_model
    """
    film_phase_change_model child of wall_child.
    """
    film_cond_const: film_cond_const = film_cond_const
    """
    film_cond_const child of wall_child.
    """
    film_vapo_const: film_vapo_const = film_vapo_const
    """
    film_vapo_const child of wall_child.
    """
    film_cond_rate: film_cond_rate = film_cond_rate
    """
    film_cond_rate child of wall_child.
    """
    film_vapo_rate: film_vapo_rate = film_vapo_rate
    """
    film_vapo_rate child of wall_child.
    """
    film_momentum_coupling: film_momentum_coupling = film_momentum_coupling
    """
    film_momentum_coupling child of wall_child.
    """
    film_splash_wall: film_splash_wall = film_splash_wall
    """
    film_splash_wall child of wall_child.
    """
    film_boundary_separation: film_boundary_separation = film_boundary_separation
    """
    film_boundary_separation child of wall_child.
    """
    film_impinge_model: film_impinge_model = film_impinge_model
    """
    film_impinge_model child of wall_child.
    """
    film_splash_nparc: film_splash_nparc = film_splash_nparc
    """
    film_splash_nparc child of wall_child.
    """
    film_crit_temp_factor: film_crit_temp_factor = film_crit_temp_factor
    """
    film_crit_temp_factor child of wall_child.
    """
    film_roughness_ra: film_roughness_ra = film_roughness_ra
    """
    film_roughness_ra child of wall_child.
    """
    film_roughness_rz: film_roughness_rz = film_roughness_rz
    """
    film_roughness_rz child of wall_child.
    """
    film_upper_deposition_limit_offset: film_upper_deposition_limit_offset = film_upper_deposition_limit_offset
    """
    film_upper_deposition_limit_offset child of wall_child.
    """
    film_deposition_delta_t: film_deposition_delta_t = film_deposition_delta_t
    """
    film_deposition_delta_t child of wall_child.
    """
    film_laplace_number_constant: film_laplace_number_constant = film_laplace_number_constant
    """
    film_laplace_number_constant child of wall_child.
    """
    film_partial_evap_ratio: film_partial_evap_ratio = film_partial_evap_ratio
    """
    film_partial_evap_ratio child of wall_child.
    """
    film_contact_angle: film_contact_angle = film_contact_angle
    """
    film_contact_angle child of wall_child.
    """
    film_contact_angle_mean: film_contact_angle_mean = film_contact_angle_mean
    """
    film_contact_angle_mean child of wall_child.
    """
    film_contact_angle_rstd: film_contact_angle_rstd = film_contact_angle_rstd
    """
    film_contact_angle_rstd child of wall_child.
    """
    film_contact_angle_beta: film_contact_angle_beta = film_contact_angle_beta
    """
    film_contact_angle_beta child of wall_child.
    """
    film_vof_coupling_high: film_vof_coupling_high = film_vof_coupling_high
    """
    film_vof_coupling_high child of wall_child.
    """
    film_vof_trans_high: film_vof_trans_high = film_vof_trans_high
    """
    film_vof_trans_high child of wall_child.
    """
    film_vof_trans_high_relax: film_vof_trans_high_relax = film_vof_trans_high_relax
    """
    film_vof_trans_high_relax child of wall_child.
    """
    film_vof_coupling_low: film_vof_coupling_low = film_vof_coupling_low
    """
    film_vof_coupling_low child of wall_child.
    """
    film_vof_trans_low: film_vof_trans_low = film_vof_trans_low
    """
    film_vof_trans_low child of wall_child.
    """
    film_vof_trans_low_relax: film_vof_trans_low_relax = film_vof_trans_low_relax
    """
    film_vof_trans_low_relax child of wall_child.
    """
    caf: caf = caf
    """
    caf child of wall_child.
    """
    thermal_stabilization: thermal_stabilization = thermal_stabilization
    """
    thermal_stabilization child of wall_child.
    """
    scale_factor: scale_factor = scale_factor
    """
    scale_factor child of wall_child.
    """
    stab_method: stab_method = stab_method
    """
    stab_method child of wall_child.
    """
    fensapice_flow_bc_subtype: fensapice_flow_bc_subtype = fensapice_flow_bc_subtype
    """
    fensapice_flow_bc_subtype child of wall_child.
    """
    fensapice_ice_icing_mode: fensapice_ice_icing_mode = fensapice_ice_icing_mode
    """
    fensapice_ice_icing_mode child of wall_child.
    """
    fensapice_ice_hflux: fensapice_ice_hflux = fensapice_ice_hflux
    """
    fensapice_ice_hflux child of wall_child.
    """
    fensapice_ice_hflux_1: fensapice_ice_hflux_1 = fensapice_ice_hflux_1
    """
    fensapice_ice_hflux_1 child of wall_child.
    """
    fensapice_drop_vwet: fensapice_drop_vwet = fensapice_drop_vwet
    """
    fensapice_drop_vwet child of wall_child.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .axis_direction_component_child import axis_direction_component_child

class direction_component_of_rotation_axis(ListObject[axis_direction_component_child]):
    """
    'direction_component_of_rotation_axis' child.
    """

    fluent_name = "direction-component-of-rotation-axis"

    child_object_type: axis_direction_component_child = axis_direction_component_child
    """
    child_object_type of direction_component_of_rotation_axis.
    """
